# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class KeyShape(object):
    """
    The cryptographic properties of a key.
    """

    #: A constant which can be used with the algorithm property of a KeyShape.
    #: This constant has a value of "AES"
    ALGORITHM_AES = "AES"

    #: A constant which can be used with the algorithm property of a KeyShape.
    #: This constant has a value of "RSA"
    ALGORITHM_RSA = "RSA"

    def __init__(self, **kwargs):
        """
        Initializes a new KeyShape object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param algorithm:
            The value to assign to the algorithm property of this KeyShape.
            Allowed values for this property are: "AES", "RSA", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type algorithm: str

        :param length:
            The value to assign to the length property of this KeyShape.
        :type length: int

        """
        self.swagger_types = {
            'algorithm': 'str',
            'length': 'int'
        }

        self.attribute_map = {
            'algorithm': 'algorithm',
            'length': 'length'
        }

        self._algorithm = None
        self._length = None

    @property
    def algorithm(self):
        """
        **[Required]** Gets the algorithm of this KeyShape.
        The algorithm used by a key's key versions to encrypt or decrypt.

        Allowed values for this property are: "AES", "RSA", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The algorithm of this KeyShape.
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """
        Sets the algorithm of this KeyShape.
        The algorithm used by a key's key versions to encrypt or decrypt.


        :param algorithm: The algorithm of this KeyShape.
        :type: str
        """
        allowed_values = ["AES", "RSA"]
        if not value_allowed_none_or_none_sentinel(algorithm, allowed_values):
            algorithm = 'UNKNOWN_ENUM_VALUE'
        self._algorithm = algorithm

    @property
    def length(self):
        """
        **[Required]** Gets the length of this KeyShape.
        The length of the key, expressed as an integer. Values of 16, 24, or 32 are supported.


        :return: The length of this KeyShape.
        :rtype: int
        """
        return self._length

    @length.setter
    def length(self, length):
        """
        Sets the length of this KeyShape.
        The length of the key, expressed as an integer. Values of 16, 24, or 32 are supported.


        :param length: The length of this KeyShape.
        :type: int
        """
        self._length = length

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutonomousDatabaseBackupSummary(object):
    """
    An Autonomous Database backup.
    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see `Getting Started with Policies`__.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the type property of a AutonomousDatabaseBackupSummary.
    #: This constant has a value of "INCREMENTAL"
    TYPE_INCREMENTAL = "INCREMENTAL"

    #: A constant which can be used with the type property of a AutonomousDatabaseBackupSummary.
    #: This constant has a value of "FULL"
    TYPE_FULL = "FULL"

    #: A constant which can be used with the lifecycle_state property of a AutonomousDatabaseBackupSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a AutonomousDatabaseBackupSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a AutonomousDatabaseBackupSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a AutonomousDatabaseBackupSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a AutonomousDatabaseBackupSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new AutonomousDatabaseBackupSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AutonomousDatabaseBackupSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this AutonomousDatabaseBackupSummary.
        :type compartment_id: str

        :param autonomous_database_id:
            The value to assign to the autonomous_database_id property of this AutonomousDatabaseBackupSummary.
        :type autonomous_database_id: str

        :param display_name:
            The value to assign to the display_name property of this AutonomousDatabaseBackupSummary.
        :type display_name: str

        :param type:
            The value to assign to the type property of this AutonomousDatabaseBackupSummary.
            Allowed values for this property are: "INCREMENTAL", "FULL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param is_automatic:
            The value to assign to the is_automatic property of this AutonomousDatabaseBackupSummary.
        :type is_automatic: bool

        :param time_started:
            The value to assign to the time_started property of this AutonomousDatabaseBackupSummary.
        :type time_started: datetime

        :param time_ended:
            The value to assign to the time_ended property of this AutonomousDatabaseBackupSummary.
        :type time_ended: datetime

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this AutonomousDatabaseBackupSummary.
        :type lifecycle_details: str

        :param database_size_in_tbs:
            The value to assign to the database_size_in_tbs property of this AutonomousDatabaseBackupSummary.
        :type database_size_in_tbs: float

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AutonomousDatabaseBackupSummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param is_restorable:
            The value to assign to the is_restorable property of this AutonomousDatabaseBackupSummary.
        :type is_restorable: bool

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'autonomous_database_id': 'str',
            'display_name': 'str',
            'type': 'str',
            'is_automatic': 'bool',
            'time_started': 'datetime',
            'time_ended': 'datetime',
            'lifecycle_details': 'str',
            'database_size_in_tbs': 'float',
            'lifecycle_state': 'str',
            'is_restorable': 'bool'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'autonomous_database_id': 'autonomousDatabaseId',
            'display_name': 'displayName',
            'type': 'type',
            'is_automatic': 'isAutomatic',
            'time_started': 'timeStarted',
            'time_ended': 'timeEnded',
            'lifecycle_details': 'lifecycleDetails',
            'database_size_in_tbs': 'databaseSizeInTBs',
            'lifecycle_state': 'lifecycleState',
            'is_restorable': 'isRestorable'
        }

        self._id = None
        self._compartment_id = None
        self._autonomous_database_id = None
        self._display_name = None
        self._type = None
        self._is_automatic = None
        self._time_started = None
        self._time_ended = None
        self._lifecycle_details = None
        self._database_size_in_tbs = None
        self._lifecycle_state = None
        self._is_restorable = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this AutonomousDatabaseBackupSummary.
        The `OCID`__ of the Autonomous Database backup.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this AutonomousDatabaseBackupSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AutonomousDatabaseBackupSummary.
        The `OCID`__ of the Autonomous Database backup.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this AutonomousDatabaseBackupSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this AutonomousDatabaseBackupSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this AutonomousDatabaseBackupSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this AutonomousDatabaseBackupSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this AutonomousDatabaseBackupSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def autonomous_database_id(self):
        """
        **[Required]** Gets the autonomous_database_id of this AutonomousDatabaseBackupSummary.
        The `OCID`__ of the Autonomous Database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The autonomous_database_id of this AutonomousDatabaseBackupSummary.
        :rtype: str
        """
        return self._autonomous_database_id

    @autonomous_database_id.setter
    def autonomous_database_id(self, autonomous_database_id):
        """
        Sets the autonomous_database_id of this AutonomousDatabaseBackupSummary.
        The `OCID`__ of the Autonomous Database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param autonomous_database_id: The autonomous_database_id of this AutonomousDatabaseBackupSummary.
        :type: str
        """
        self._autonomous_database_id = autonomous_database_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this AutonomousDatabaseBackupSummary.
        The user-friendly name for the backup. The name does not have to be unique.


        :return: The display_name of this AutonomousDatabaseBackupSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this AutonomousDatabaseBackupSummary.
        The user-friendly name for the backup. The name does not have to be unique.


        :param display_name: The display_name of this AutonomousDatabaseBackupSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def type(self):
        """
        **[Required]** Gets the type of this AutonomousDatabaseBackupSummary.
        The type of backup.

        Allowed values for this property are: "INCREMENTAL", "FULL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this AutonomousDatabaseBackupSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this AutonomousDatabaseBackupSummary.
        The type of backup.


        :param type: The type of this AutonomousDatabaseBackupSummary.
        :type: str
        """
        allowed_values = ["INCREMENTAL", "FULL"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def is_automatic(self):
        """
        **[Required]** Gets the is_automatic of this AutonomousDatabaseBackupSummary.
        Indicates whether the backup is user-initiated or automatic.


        :return: The is_automatic of this AutonomousDatabaseBackupSummary.
        :rtype: bool
        """
        return self._is_automatic

    @is_automatic.setter
    def is_automatic(self, is_automatic):
        """
        Sets the is_automatic of this AutonomousDatabaseBackupSummary.
        Indicates whether the backup is user-initiated or automatic.


        :param is_automatic: The is_automatic of this AutonomousDatabaseBackupSummary.
        :type: bool
        """
        self._is_automatic = is_automatic

    @property
    def time_started(self):
        """
        Gets the time_started of this AutonomousDatabaseBackupSummary.
        The date and time the backup started.


        :return: The time_started of this AutonomousDatabaseBackupSummary.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this AutonomousDatabaseBackupSummary.
        The date and time the backup started.


        :param time_started: The time_started of this AutonomousDatabaseBackupSummary.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_ended(self):
        """
        Gets the time_ended of this AutonomousDatabaseBackupSummary.
        The date and time the backup completed.


        :return: The time_ended of this AutonomousDatabaseBackupSummary.
        :rtype: datetime
        """
        return self._time_ended

    @time_ended.setter
    def time_ended(self, time_ended):
        """
        Sets the time_ended of this AutonomousDatabaseBackupSummary.
        The date and time the backup completed.


        :param time_ended: The time_ended of this AutonomousDatabaseBackupSummary.
        :type: datetime
        """
        self._time_ended = time_ended

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this AutonomousDatabaseBackupSummary.
        Additional information about the current lifecycle state.


        :return: The lifecycle_details of this AutonomousDatabaseBackupSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this AutonomousDatabaseBackupSummary.
        Additional information about the current lifecycle state.


        :param lifecycle_details: The lifecycle_details of this AutonomousDatabaseBackupSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def database_size_in_tbs(self):
        """
        Gets the database_size_in_tbs of this AutonomousDatabaseBackupSummary.
        The size of the database in terabytes at the time the backup was taken.


        :return: The database_size_in_tbs of this AutonomousDatabaseBackupSummary.
        :rtype: float
        """
        return self._database_size_in_tbs

    @database_size_in_tbs.setter
    def database_size_in_tbs(self, database_size_in_tbs):
        """
        Sets the database_size_in_tbs of this AutonomousDatabaseBackupSummary.
        The size of the database in terabytes at the time the backup was taken.


        :param database_size_in_tbs: The database_size_in_tbs of this AutonomousDatabaseBackupSummary.
        :type: float
        """
        self._database_size_in_tbs = database_size_in_tbs

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this AutonomousDatabaseBackupSummary.
        The current state of the backup.

        Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this AutonomousDatabaseBackupSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this AutonomousDatabaseBackupSummary.
        The current state of the backup.


        :param lifecycle_state: The lifecycle_state of this AutonomousDatabaseBackupSummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def is_restorable(self):
        """
        Gets the is_restorable of this AutonomousDatabaseBackupSummary.
        Indicates whether the backup can be used to restore the associated Autonomous Database.


        :return: The is_restorable of this AutonomousDatabaseBackupSummary.
        :rtype: bool
        """
        return self._is_restorable

    @is_restorable.setter
    def is_restorable(self, is_restorable):
        """
        Sets the is_restorable of this AutonomousDatabaseBackupSummary.
        Indicates whether the backup can be used to restore the associated Autonomous Database.


        :param is_restorable: The is_restorable of this AutonomousDatabaseBackupSummary.
        :type: bool
        """
        self._is_restorable = is_restorable

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SteeringPolicyRule(object):
    """
    The configuration of the sorting and filtering behaviors in a steering policy. Rules can
    filter and sort answers based on weight, priority, endpoint health, and other data.


    A rule may optionally include a sequence of cases, each with an optional `caseCondition`
    expression. Cases allow a sequence of conditions to be defined that will apply different
    parameters to the rule when the conditions are met. For more information about cases,
    see `Traffic Management API Guide`__.


    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.

    __ https://docs.cloud.oracle.com/iaas/Content/TrafficManagement/Concepts/trafficmanagementapi.htm
    """

    #: A constant which can be used with the rule_type property of a SteeringPolicyRule.
    #: This constant has a value of "FILTER"
    RULE_TYPE_FILTER = "FILTER"

    #: A constant which can be used with the rule_type property of a SteeringPolicyRule.
    #: This constant has a value of "HEALTH"
    RULE_TYPE_HEALTH = "HEALTH"

    #: A constant which can be used with the rule_type property of a SteeringPolicyRule.
    #: This constant has a value of "WEIGHTED"
    RULE_TYPE_WEIGHTED = "WEIGHTED"

    #: A constant which can be used with the rule_type property of a SteeringPolicyRule.
    #: This constant has a value of "PRIORITY"
    RULE_TYPE_PRIORITY = "PRIORITY"

    #: A constant which can be used with the rule_type property of a SteeringPolicyRule.
    #: This constant has a value of "LIMIT"
    RULE_TYPE_LIMIT = "LIMIT"

    def __init__(self, **kwargs):
        """
        Initializes a new SteeringPolicyRule object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.dns.models.SteeringPolicyFilterRule`
        * :class:`~oci.dns.models.SteeringPolicyWeightedRule`
        * :class:`~oci.dns.models.SteeringPolicyLimitRule`
        * :class:`~oci.dns.models.SteeringPolicyHealthRule`
        * :class:`~oci.dns.models.SteeringPolicyPriorityRule`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this SteeringPolicyRule.
        :type description: str

        :param rule_type:
            The value to assign to the rule_type property of this SteeringPolicyRule.
            Allowed values for this property are: "FILTER", "HEALTH", "WEIGHTED", "PRIORITY", "LIMIT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type rule_type: str

        """
        self.swagger_types = {
            'description': 'str',
            'rule_type': 'str'
        }

        self.attribute_map = {
            'description': 'description',
            'rule_type': 'ruleType'
        }

        self._description = None
        self._rule_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['ruleType']

        if type == 'FILTER':
            return 'SteeringPolicyFilterRule'

        if type == 'WEIGHTED':
            return 'SteeringPolicyWeightedRule'

        if type == 'LIMIT':
            return 'SteeringPolicyLimitRule'

        if type == 'HEALTH':
            return 'SteeringPolicyHealthRule'

        if type == 'PRIORITY':
            return 'SteeringPolicyPriorityRule'
        else:
            return 'SteeringPolicyRule'

    @property
    def description(self):
        """
        Gets the description of this SteeringPolicyRule.
        A user-defined description of the rule's purpose or behavior.


        :return: The description of this SteeringPolicyRule.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this SteeringPolicyRule.
        A user-defined description of the rule's purpose or behavior.


        :param description: The description of this SteeringPolicyRule.
        :type: str
        """
        self._description = description

    @property
    def rule_type(self):
        """
        **[Required]** Gets the rule_type of this SteeringPolicyRule.
        The type of a rule determines its sorting/filtering behavior.
        * `FILTER` - Filters the list of answers based on their defined boolean data. Answers remain
          only if their `shouldKeep` value is `true`.


        * `HEALTH` - Removes answers from the list if their `rdata` matches a target in the
          health check monitor referenced by the steering policy and the target is reported down.


        * `WEIGHTED` - Uses a number between 0 and 255 to determine how often an answer will be served
          in relation to other answers. Anwers with a higher weight will be served more frequently.


        * `PRIORITY` - Uses a defined rank value of answers to determine which answer to serve,
          moving those with the lowest values to the beginning of the list without changing the
          relative order of those with the same value. Answers can be given a value between `0` and `255`.


        * `LIMIT` - Filters answers that are too far down the list. Parameter `defaultCount`
          specifies how many answers to keep. **Example:** If `defaultCount` has a value of `2` and
          there are five answers left, when the `LIMIT` rule is processed, only the first two answers
          will remain in the list.

        Allowed values for this property are: "FILTER", "HEALTH", "WEIGHTED", "PRIORITY", "LIMIT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The rule_type of this SteeringPolicyRule.
        :rtype: str
        """
        return self._rule_type

    @rule_type.setter
    def rule_type(self, rule_type):
        """
        Sets the rule_type of this SteeringPolicyRule.
        The type of a rule determines its sorting/filtering behavior.
        * `FILTER` - Filters the list of answers based on their defined boolean data. Answers remain
          only if their `shouldKeep` value is `true`.


        * `HEALTH` - Removes answers from the list if their `rdata` matches a target in the
          health check monitor referenced by the steering policy and the target is reported down.


        * `WEIGHTED` - Uses a number between 0 and 255 to determine how often an answer will be served
          in relation to other answers. Anwers with a higher weight will be served more frequently.


        * `PRIORITY` - Uses a defined rank value of answers to determine which answer to serve,
          moving those with the lowest values to the beginning of the list without changing the
          relative order of those with the same value. Answers can be given a value between `0` and `255`.


        * `LIMIT` - Filters answers that are too far down the list. Parameter `defaultCount`
          specifies how many answers to keep. **Example:** If `defaultCount` has a value of `2` and
          there are five answers left, when the `LIMIT` rule is processed, only the first two answers
          will remain in the list.


        :param rule_type: The rule_type of this SteeringPolicyRule.
        :type: str
        """
        allowed_values = ["FILTER", "HEALTH", "WEIGHTED", "PRIORITY", "LIMIT"]
        if not value_allowed_none_or_none_sentinel(rule_type, allowed_values):
            rule_type = 'UNKNOWN_ENUM_VALUE'
        self._rule_type = rule_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_field import AbstractField
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SortField(AbstractField):
    """
    Field outlining queryString sort command fields and their corresponding sort order.
    """

    #: A constant which can be used with the direction property of a SortField.
    #: This constant has a value of "ASCENDING"
    DIRECTION_ASCENDING = "ASCENDING"

    #: A constant which can be used with the direction property of a SortField.
    #: This constant has a value of "DESCENDING"
    DIRECTION_DESCENDING = "DESCENDING"

    def __init__(self, **kwargs):
        """
        Initializes a new SortField object with values from keyword arguments. The default value of the :py:attr:`~oci.log_analytics.models.SortField.name` attribute
        of this class is ``SORT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this SortField.
            Allowed values for this property are: "FIELD", "FIELDS", "FUNCTION", "SORT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type name: str

        :param display_name:
            The value to assign to the display_name property of this SortField.
        :type display_name: str

        :param is_declared:
            The value to assign to the is_declared property of this SortField.
        :type is_declared: bool

        :param original_display_names:
            The value to assign to the original_display_names property of this SortField.
        :type original_display_names: list[str]

        :param internal_name:
            The value to assign to the internal_name property of this SortField.
        :type internal_name: str

        :param value_type:
            The value to assign to the value_type property of this SortField.
            Allowed values for this property are: "BOOLEAN", "STRING", "DOUBLE", "FLOAT", "LONG", "INTEGER", "TIMESTAMP", "FACET", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type value_type: str

        :param is_groupable:
            The value to assign to the is_groupable property of this SortField.
        :type is_groupable: bool

        :param is_duration:
            The value to assign to the is_duration property of this SortField.
        :type is_duration: bool

        :param alias:
            The value to assign to the alias property of this SortField.
        :type alias: str

        :param filter_query_string:
            The value to assign to the filter_query_string property of this SortField.
        :type filter_query_string: str

        :param direction:
            The value to assign to the direction property of this SortField.
            Allowed values for this property are: "ASCENDING", "DESCENDING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type direction: str

        """
        self.swagger_types = {
            'name': 'str',
            'display_name': 'str',
            'is_declared': 'bool',
            'original_display_names': 'list[str]',
            'internal_name': 'str',
            'value_type': 'str',
            'is_groupable': 'bool',
            'is_duration': 'bool',
            'alias': 'str',
            'filter_query_string': 'str',
            'direction': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'display_name': 'displayName',
            'is_declared': 'isDeclared',
            'original_display_names': 'originalDisplayNames',
            'internal_name': 'internalName',
            'value_type': 'valueType',
            'is_groupable': 'isGroupable',
            'is_duration': 'isDuration',
            'alias': 'alias',
            'filter_query_string': 'filterQueryString',
            'direction': 'direction'
        }

        self._name = None
        self._display_name = None
        self._is_declared = None
        self._original_display_names = None
        self._internal_name = None
        self._value_type = None
        self._is_groupable = None
        self._is_duration = None
        self._alias = None
        self._filter_query_string = None
        self._direction = None
        self._name = 'SORT'

    @property
    def direction(self):
        """
        Gets the direction of this SortField.
        Sort order for the field specified in the queryString.

        Allowed values for this property are: "ASCENDING", "DESCENDING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The direction of this SortField.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this SortField.
        Sort order for the field specified in the queryString.


        :param direction: The direction of this SortField.
        :type: str
        """
        allowed_values = ["ASCENDING", "DESCENDING"]
        if not value_allowed_none_or_none_sentinel(direction, allowed_values):
            direction = 'UNKNOWN_ENUM_VALUE'
        self._direction = direction

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AbstractParserTestResultLogEntry(object):
    """
    AbstractParserTestResultLogEntry
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AbstractParserTestResultLogEntry object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param extra_info_attributes:
            The value to assign to the extra_info_attributes property of this AbstractParserTestResultLogEntry.
        :type extra_info_attributes: dict(str, str)

        :param field_name_value_map:
            The value to assign to the field_name_value_map property of this AbstractParserTestResultLogEntry.
        :type field_name_value_map: dict(str, str)

        :param field_position_value_map:
            The value to assign to the field_position_value_map property of this AbstractParserTestResultLogEntry.
        :type field_position_value_map: dict(str, str)

        :param fields:
            The value to assign to the fields property of this AbstractParserTestResultLogEntry.
        :type fields: dict(str, str)

        :param log_entry:
            The value to assign to the log_entry property of this AbstractParserTestResultLogEntry.
        :type log_entry: str

        :param match_status:
            The value to assign to the match_status property of this AbstractParserTestResultLogEntry.
        :type match_status: str

        :param match_status_description:
            The value to assign to the match_status_description property of this AbstractParserTestResultLogEntry.
        :type match_status_description: str

        """
        self.swagger_types = {
            'extra_info_attributes': 'dict(str, str)',
            'field_name_value_map': 'dict(str, str)',
            'field_position_value_map': 'dict(str, str)',
            'fields': 'dict(str, str)',
            'log_entry': 'str',
            'match_status': 'str',
            'match_status_description': 'str'
        }

        self.attribute_map = {
            'extra_info_attributes': 'extraInfoAttributes',
            'field_name_value_map': 'fieldNameValueMap',
            'field_position_value_map': 'fieldPositionValueMap',
            'fields': 'fields',
            'log_entry': 'logEntry',
            'match_status': 'matchStatus',
            'match_status_description': 'matchStatusDescription'
        }

        self._extra_info_attributes = None
        self._field_name_value_map = None
        self._field_position_value_map = None
        self._fields = None
        self._log_entry = None
        self._match_status = None
        self._match_status_description = None

    @property
    def extra_info_attributes(self):
        """
        Gets the extra_info_attributes of this AbstractParserTestResultLogEntry.
        extra info attributes


        :return: The extra_info_attributes of this AbstractParserTestResultLogEntry.
        :rtype: dict(str, str)
        """
        return self._extra_info_attributes

    @extra_info_attributes.setter
    def extra_info_attributes(self, extra_info_attributes):
        """
        Sets the extra_info_attributes of this AbstractParserTestResultLogEntry.
        extra info attributes


        :param extra_info_attributes: The extra_info_attributes of this AbstractParserTestResultLogEntry.
        :type: dict(str, str)
        """
        self._extra_info_attributes = extra_info_attributes

    @property
    def field_name_value_map(self):
        """
        Gets the field_name_value_map of this AbstractParserTestResultLogEntry.
        field name value map


        :return: The field_name_value_map of this AbstractParserTestResultLogEntry.
        :rtype: dict(str, str)
        """
        return self._field_name_value_map

    @field_name_value_map.setter
    def field_name_value_map(self, field_name_value_map):
        """
        Sets the field_name_value_map of this AbstractParserTestResultLogEntry.
        field name value map


        :param field_name_value_map: The field_name_value_map of this AbstractParserTestResultLogEntry.
        :type: dict(str, str)
        """
        self._field_name_value_map = field_name_value_map

    @property
    def field_position_value_map(self):
        """
        Gets the field_position_value_map of this AbstractParserTestResultLogEntry.
        field position value map


        :return: The field_position_value_map of this AbstractParserTestResultLogEntry.
        :rtype: dict(str, str)
        """
        return self._field_position_value_map

    @field_position_value_map.setter
    def field_position_value_map(self, field_position_value_map):
        """
        Sets the field_position_value_map of this AbstractParserTestResultLogEntry.
        field position value map


        :param field_position_value_map: The field_position_value_map of this AbstractParserTestResultLogEntry.
        :type: dict(str, str)
        """
        self._field_position_value_map = field_position_value_map

    @property
    def fields(self):
        """
        Gets the fields of this AbstractParserTestResultLogEntry.
        fields


        :return: The fields of this AbstractParserTestResultLogEntry.
        :rtype: dict(str, str)
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """
        Sets the fields of this AbstractParserTestResultLogEntry.
        fields


        :param fields: The fields of this AbstractParserTestResultLogEntry.
        :type: dict(str, str)
        """
        self._fields = fields

    @property
    def log_entry(self):
        """
        Gets the log_entry of this AbstractParserTestResultLogEntry.
        log entry


        :return: The log_entry of this AbstractParserTestResultLogEntry.
        :rtype: str
        """
        return self._log_entry

    @log_entry.setter
    def log_entry(self, log_entry):
        """
        Sets the log_entry of this AbstractParserTestResultLogEntry.
        log entry


        :param log_entry: The log_entry of this AbstractParserTestResultLogEntry.
        :type: str
        """
        self._log_entry = log_entry

    @property
    def match_status(self):
        """
        Gets the match_status of this AbstractParserTestResultLogEntry.
        match status


        :return: The match_status of this AbstractParserTestResultLogEntry.
        :rtype: str
        """
        return self._match_status

    @match_status.setter
    def match_status(self, match_status):
        """
        Sets the match_status of this AbstractParserTestResultLogEntry.
        match status


        :param match_status: The match_status of this AbstractParserTestResultLogEntry.
        :type: str
        """
        self._match_status = match_status

    @property
    def match_status_description(self):
        """
        Gets the match_status_description of this AbstractParserTestResultLogEntry.
        match status description


        :return: The match_status_description of this AbstractParserTestResultLogEntry.
        :rtype: str
        """
        return self._match_status_description

    @match_status_description.setter
    def match_status_description(self, match_status_description):
        """
        Sets the match_status_description of this AbstractParserTestResultLogEntry.
        match status description


        :param match_status_description: The match_status_description of this AbstractParserTestResultLogEntry.
        :type: str
        """
        self._match_status_description = match_status_description

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2018, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Original Work: Copyright (c) 2018 Character Encoding Detector contributors.  https://github.com/chardet

from .charsetgroupprober import CharSetGroupProber
from .utf8prober import UTF8Prober
from .sjisprober import SJISProber
from .eucjpprober import EUCJPProber
from .gb2312prober import GB2312Prober
from .euckrprober import EUCKRProber
from .cp949prober import CP949Prober
from .big5prober import Big5Prober
from .euctwprober import EUCTWProber


class MBCSGroupProber(CharSetGroupProber):
    def __init__(self, lang_filter=None):
        super(MBCSGroupProber, self).__init__(lang_filter=lang_filter)
        self.probers = [
            UTF8Prober(),
            SJISProber(),
            EUCJPProber(),
            GB2312Prober(),
            EUCKRProber(),
            CP949Prober(),
            Big5Prober(),
            EUCTWProber()
        ]
        self.reset()



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .change_model_compartment_details import ChangeModelCompartmentDetails
from .change_notebook_session_compartment_details import ChangeNotebookSessionCompartmentDetails
from .change_project_compartment_details import ChangeProjectCompartmentDetails
from .create_model_details import CreateModelDetails
from .create_model_provenance_details import CreateModelProvenanceDetails
from .create_notebook_session_details import CreateNotebookSessionDetails
from .create_project_details import CreateProjectDetails
from .model import Model
from .model_provenance import ModelProvenance
from .model_summary import ModelSummary
from .notebook_session import NotebookSession
from .notebook_session_configuration_details import NotebookSessionConfigurationDetails
from .notebook_session_shape_summary import NotebookSessionShapeSummary
from .notebook_session_summary import NotebookSessionSummary
from .project import Project
from .project_summary import ProjectSummary
from .update_model_details import UpdateModelDetails
from .update_model_provenance_details import UpdateModelProvenanceDetails
from .update_notebook_session_details import UpdateNotebookSessionDetails
from .update_project_details import UpdateProjectDetails
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for data_science services.
data_science_type_mapping = {
    "ChangeModelCompartmentDetails": ChangeModelCompartmentDetails,
    "ChangeNotebookSessionCompartmentDetails": ChangeNotebookSessionCompartmentDetails,
    "ChangeProjectCompartmentDetails": ChangeProjectCompartmentDetails,
    "CreateModelDetails": CreateModelDetails,
    "CreateModelProvenanceDetails": CreateModelProvenanceDetails,
    "CreateNotebookSessionDetails": CreateNotebookSessionDetails,
    "CreateProjectDetails": CreateProjectDetails,
    "Model": Model,
    "ModelProvenance": ModelProvenance,
    "ModelSummary": ModelSummary,
    "NotebookSession": NotebookSession,
    "NotebookSessionConfigurationDetails": NotebookSessionConfigurationDetails,
    "NotebookSessionShapeSummary": NotebookSessionShapeSummary,
    "NotebookSessionSummary": NotebookSessionSummary,
    "Project": Project,
    "ProjectSummary": ProjectSummary,
    "UpdateModelDetails": UpdateModelDetails,
    "UpdateModelProvenanceDetails": UpdateModelProvenanceDetails,
    "UpdateNotebookSessionDetails": UpdateNotebookSessionDetails,
    "UpdateProjectDetails": UpdateProjectDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Month(object):
    """
    Month of the year.
    """

    #: A constant which can be used with the name property of a Month.
    #: This constant has a value of "JANUARY"
    NAME_JANUARY = "JANUARY"

    #: A constant which can be used with the name property of a Month.
    #: This constant has a value of "FEBRUARY"
    NAME_FEBRUARY = "FEBRUARY"

    #: A constant which can be used with the name property of a Month.
    #: This constant has a value of "MARCH"
    NAME_MARCH = "MARCH"

    #: A constant which can be used with the name property of a Month.
    #: This constant has a value of "APRIL"
    NAME_APRIL = "APRIL"

    #: A constant which can be used with the name property of a Month.
    #: This constant has a value of "MAY"
    NAME_MAY = "MAY"

    #: A constant which can be used with the name property of a Month.
    #: This constant has a value of "JUNE"
    NAME_JUNE = "JUNE"

    #: A constant which can be used with the name property of a Month.
    #: This constant has a value of "JULY"
    NAME_JULY = "JULY"

    #: A constant which can be used with the name property of a Month.
    #: This constant has a value of "AUGUST"
    NAME_AUGUST = "AUGUST"

    #: A constant which can be used with the name property of a Month.
    #: This constant has a value of "SEPTEMBER"
    NAME_SEPTEMBER = "SEPTEMBER"

    #: A constant which can be used with the name property of a Month.
    #: This constant has a value of "OCTOBER"
    NAME_OCTOBER = "OCTOBER"

    #: A constant which can be used with the name property of a Month.
    #: This constant has a value of "NOVEMBER"
    NAME_NOVEMBER = "NOVEMBER"

    #: A constant which can be used with the name property of a Month.
    #: This constant has a value of "DECEMBER"
    NAME_DECEMBER = "DECEMBER"

    def __init__(self, **kwargs):
        """
        Initializes a new Month object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this Month.
            Allowed values for this property are: "JANUARY", "FEBRUARY", "MARCH", "APRIL", "MAY", "JUNE", "JULY", "AUGUST", "SEPTEMBER", "OCTOBER", "NOVEMBER", "DECEMBER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type name: str

        """
        self.swagger_types = {
            'name': 'str'
        }

        self.attribute_map = {
            'name': 'name'
        }

        self._name = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Month.
        Name of the month of the year.

        Allowed values for this property are: "JANUARY", "FEBRUARY", "MARCH", "APRIL", "MAY", "JUNE", "JULY", "AUGUST", "SEPTEMBER", "OCTOBER", "NOVEMBER", "DECEMBER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The name of this Month.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Month.
        Name of the month of the year.


        :param name: The name of this Month.
        :type: str
        """
        allowed_values = ["JANUARY", "FEBRUARY", "MARCH", "APRIL", "MAY", "JUNE", "JULY", "AUGUST", "SEPTEMBER", "OCTOBER", "NOVEMBER", "DECEMBER"]
        if not value_allowed_none_or_none_sentinel(name, allowed_values):
            name = 'UNKNOWN_ENUM_VALUE'
        self._name = name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceConfigurationLaunchInstanceAgentConfigDetails(object):
    """
    Instance agent configuration options to choose for launching the instance
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceConfigurationLaunchInstanceAgentConfigDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_monitoring_disabled:
            The value to assign to the is_monitoring_disabled property of this InstanceConfigurationLaunchInstanceAgentConfigDetails.
        :type is_monitoring_disabled: bool

        :param is_management_disabled:
            The value to assign to the is_management_disabled property of this InstanceConfigurationLaunchInstanceAgentConfigDetails.
        :type is_management_disabled: bool

        """
        self.swagger_types = {
            'is_monitoring_disabled': 'bool',
            'is_management_disabled': 'bool'
        }

        self.attribute_map = {
            'is_monitoring_disabled': 'isMonitoringDisabled',
            'is_management_disabled': 'isManagementDisabled'
        }

        self._is_monitoring_disabled = None
        self._is_management_disabled = None

    @property
    def is_monitoring_disabled(self):
        """
        Gets the is_monitoring_disabled of this InstanceConfigurationLaunchInstanceAgentConfigDetails.
        Whether the agent running on the instance can gather performance metrics and monitor the instance.
        Default value is false.


        :return: The is_monitoring_disabled of this InstanceConfigurationLaunchInstanceAgentConfigDetails.
        :rtype: bool
        """
        return self._is_monitoring_disabled

    @is_monitoring_disabled.setter
    def is_monitoring_disabled(self, is_monitoring_disabled):
        """
        Sets the is_monitoring_disabled of this InstanceConfigurationLaunchInstanceAgentConfigDetails.
        Whether the agent running on the instance can gather performance metrics and monitor the instance.
        Default value is false.


        :param is_monitoring_disabled: The is_monitoring_disabled of this InstanceConfigurationLaunchInstanceAgentConfigDetails.
        :type: bool
        """
        self._is_monitoring_disabled = is_monitoring_disabled

    @property
    def is_management_disabled(self):
        """
        Gets the is_management_disabled of this InstanceConfigurationLaunchInstanceAgentConfigDetails.
        Whether the agent running on the instance can run all the available management plugins.
        Default value is false.


        :return: The is_management_disabled of this InstanceConfigurationLaunchInstanceAgentConfigDetails.
        :rtype: bool
        """
        return self._is_management_disabled

    @is_management_disabled.setter
    def is_management_disabled(self, is_management_disabled):
        """
        Sets the is_management_disabled of this InstanceConfigurationLaunchInstanceAgentConfigDetails.
        Whether the agent running on the instance can run all the available management plugins.
        Default value is false.


        :param is_management_disabled: The is_management_disabled of this InstanceConfigurationLaunchInstanceAgentConfigDetails.
        :type: bool
        """
        self._is_management_disabled = is_management_disabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SupportContact(object):
    """
    Contact information to use to get support.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SupportContact object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this SupportContact.
        :type name: str

        :param phone:
            The value to assign to the phone property of this SupportContact.
        :type phone: str

        :param email:
            The value to assign to the email property of this SupportContact.
        :type email: str

        :param subject:
            The value to assign to the subject property of this SupportContact.
        :type subject: str

        """
        self.swagger_types = {
            'name': 'str',
            'phone': 'str',
            'email': 'str',
            'subject': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'phone': 'phone',
            'email': 'email',
            'subject': 'subject'
        }

        self._name = None
        self._phone = None
        self._email = None
        self._subject = None

    @property
    def name(self):
        """
        Gets the name of this SupportContact.
        The name of the contact.


        :return: The name of this SupportContact.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SupportContact.
        The name of the contact.


        :param name: The name of this SupportContact.
        :type: str
        """
        self._name = name

    @property
    def phone(self):
        """
        Gets the phone of this SupportContact.
        The phone number of the contact.


        :return: The phone of this SupportContact.
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """
        Sets the phone of this SupportContact.
        The phone number of the contact.


        :param phone: The phone of this SupportContact.
        :type: str
        """
        self._phone = phone

    @property
    def email(self):
        """
        Gets the email of this SupportContact.
        The email of the contact.


        :return: The email of this SupportContact.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this SupportContact.
        The email of the contact.


        :param email: The email of this SupportContact.
        :type: str
        """
        self._email = email

    @property
    def subject(self):
        """
        Gets the subject of this SupportContact.
        The email subject line to use when contacting support.


        :return: The subject of this SupportContact.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this SupportContact.
        The email subject line to use when contacting support.


        :param subject: The subject of this SupportContact.
        :type: str
        """
        self._subject = subject

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HeaderTransformationPolicy(object):
    """
    A set of transformations to apply to HTTP headers that pass through the gateway.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HeaderTransformationPolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param set_headers:
            The value to assign to the set_headers property of this HeaderTransformationPolicy.
        :type set_headers: SetHeaderPolicy

        :param rename_headers:
            The value to assign to the rename_headers property of this HeaderTransformationPolicy.
        :type rename_headers: RenameHeaderPolicy

        :param filter_headers:
            The value to assign to the filter_headers property of this HeaderTransformationPolicy.
        :type filter_headers: FilterHeaderPolicy

        """
        self.swagger_types = {
            'set_headers': 'SetHeaderPolicy',
            'rename_headers': 'RenameHeaderPolicy',
            'filter_headers': 'FilterHeaderPolicy'
        }

        self.attribute_map = {
            'set_headers': 'setHeaders',
            'rename_headers': 'renameHeaders',
            'filter_headers': 'filterHeaders'
        }

        self._set_headers = None
        self._rename_headers = None
        self._filter_headers = None

    @property
    def set_headers(self):
        """
        Gets the set_headers of this HeaderTransformationPolicy.

        :return: The set_headers of this HeaderTransformationPolicy.
        :rtype: SetHeaderPolicy
        """
        return self._set_headers

    @set_headers.setter
    def set_headers(self, set_headers):
        """
        Sets the set_headers of this HeaderTransformationPolicy.

        :param set_headers: The set_headers of this HeaderTransformationPolicy.
        :type: SetHeaderPolicy
        """
        self._set_headers = set_headers

    @property
    def rename_headers(self):
        """
        Gets the rename_headers of this HeaderTransformationPolicy.

        :return: The rename_headers of this HeaderTransformationPolicy.
        :rtype: RenameHeaderPolicy
        """
        return self._rename_headers

    @rename_headers.setter
    def rename_headers(self, rename_headers):
        """
        Sets the rename_headers of this HeaderTransformationPolicy.

        :param rename_headers: The rename_headers of this HeaderTransformationPolicy.
        :type: RenameHeaderPolicy
        """
        self._rename_headers = rename_headers

    @property
    def filter_headers(self):
        """
        Gets the filter_headers of this HeaderTransformationPolicy.

        :return: The filter_headers of this HeaderTransformationPolicy.
        :rtype: FilterHeaderPolicy
        """
        return self._filter_headers

    @filter_headers.setter
    def filter_headers(self, filter_headers):
        """
        Sets the filter_headers of this HeaderTransformationPolicy.

        :param filter_headers: The filter_headers of this HeaderTransformationPolicy.
        :type: FilterHeaderPolicy
        """
        self._filter_headers = filter_headers

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResponderRuleDetails(object):
    """
    Details of ResponderRule.
    """

    #: A constant which can be used with the mode property of a ResponderRuleDetails.
    #: This constant has a value of "AUTOACTION"
    MODE_AUTOACTION = "AUTOACTION"

    #: A constant which can be used with the mode property of a ResponderRuleDetails.
    #: This constant has a value of "USERACTION"
    MODE_USERACTION = "USERACTION"

    def __init__(self, **kwargs):
        """
        Initializes a new ResponderRuleDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param condition:
            The value to assign to the condition property of this ResponderRuleDetails.
        :type condition: Condition

        :param configurations:
            The value to assign to the configurations property of this ResponderRuleDetails.
        :type configurations: list[ResponderConfiguration]

        :param is_enabled:
            The value to assign to the is_enabled property of this ResponderRuleDetails.
        :type is_enabled: bool

        :param mode:
            The value to assign to the mode property of this ResponderRuleDetails.
            Allowed values for this property are: "AUTOACTION", "USERACTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type mode: str

        """
        self.swagger_types = {
            'condition': 'Condition',
            'configurations': 'list[ResponderConfiguration]',
            'is_enabled': 'bool',
            'mode': 'str'
        }

        self.attribute_map = {
            'condition': 'condition',
            'configurations': 'configurations',
            'is_enabled': 'isEnabled',
            'mode': 'mode'
        }

        self._condition = None
        self._configurations = None
        self._is_enabled = None
        self._mode = None

    @property
    def condition(self):
        """
        Gets the condition of this ResponderRuleDetails.

        :return: The condition of this ResponderRuleDetails.
        :rtype: Condition
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """
        Sets the condition of this ResponderRuleDetails.

        :param condition: The condition of this ResponderRuleDetails.
        :type: Condition
        """
        self._condition = condition

    @property
    def configurations(self):
        """
        Gets the configurations of this ResponderRuleDetails.
        ResponderRule configurations


        :return: The configurations of this ResponderRuleDetails.
        :rtype: list[ResponderConfiguration]
        """
        return self._configurations

    @configurations.setter
    def configurations(self, configurations):
        """
        Sets the configurations of this ResponderRuleDetails.
        ResponderRule configurations


        :param configurations: The configurations of this ResponderRuleDetails.
        :type: list[ResponderConfiguration]
        """
        self._configurations = configurations

    @property
    def is_enabled(self):
        """
        **[Required]** Gets the is_enabled of this ResponderRuleDetails.
        Identifies state for ResponderRule


        :return: The is_enabled of this ResponderRuleDetails.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this ResponderRuleDetails.
        Identifies state for ResponderRule


        :param is_enabled: The is_enabled of this ResponderRuleDetails.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def mode(self):
        """
        Gets the mode of this ResponderRuleDetails.
        Execution Mode for ResponderRule

        Allowed values for this property are: "AUTOACTION", "USERACTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The mode of this ResponderRuleDetails.
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """
        Sets the mode of this ResponderRuleDetails.
        Execution Mode for ResponderRule


        :param mode: The mode of this ResponderRuleDetails.
        :type: str
        """
        allowed_values = ["AUTOACTION", "USERACTION"]
        if not value_allowed_none_or_none_sentinel(mode, allowed_values):
            mode = 'UNKNOWN_ENUM_VALUE'
        self._mode = mode

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateKeyDetails(object):
    """
    CreateKeyDetails model.
    """

    #: A constant which can be used with the protection_mode property of a CreateKeyDetails.
    #: This constant has a value of "HSM"
    PROTECTION_MODE_HSM = "HSM"

    #: A constant which can be used with the protection_mode property of a CreateKeyDetails.
    #: This constant has a value of "SOFTWARE"
    PROTECTION_MODE_SOFTWARE = "SOFTWARE"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateKeyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateKeyDetails.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateKeyDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateKeyDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateKeyDetails.
        :type freeform_tags: dict(str, str)

        :param key_shape:
            The value to assign to the key_shape property of this CreateKeyDetails.
        :type key_shape: KeyShape

        :param protection_mode:
            The value to assign to the protection_mode property of this CreateKeyDetails.
            Allowed values for this property are: "HSM", "SOFTWARE"
        :type protection_mode: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'key_shape': 'KeyShape',
            'protection_mode': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'key_shape': 'keyShape',
            'protection_mode': 'protectionMode'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._key_shape = None
        self._protection_mode = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateKeyDetails.
        The OCID of the compartment where you want to create the master encryption key.


        :return: The compartment_id of this CreateKeyDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateKeyDetails.
        The OCID of the compartment where you want to create the master encryption key.


        :param compartment_id: The compartment_id of this CreateKeyDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateKeyDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateKeyDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateKeyDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateKeyDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateKeyDetails.
        A user-friendly name for the key. It does not have to be unique, and it is changeable.
        Avoid entering confidential information.


        :return: The display_name of this CreateKeyDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateKeyDetails.
        A user-friendly name for the key. It does not have to be unique, and it is changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this CreateKeyDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateKeyDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateKeyDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateKeyDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateKeyDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def key_shape(self):
        """
        **[Required]** Gets the key_shape of this CreateKeyDetails.

        :return: The key_shape of this CreateKeyDetails.
        :rtype: KeyShape
        """
        return self._key_shape

    @key_shape.setter
    def key_shape(self, key_shape):
        """
        Sets the key_shape of this CreateKeyDetails.

        :param key_shape: The key_shape of this CreateKeyDetails.
        :type: KeyShape
        """
        self._key_shape = key_shape

    @property
    def protection_mode(self):
        """
        Gets the protection_mode of this CreateKeyDetails.
        The key's protection mode indicates how the key persists and where cryptographic operations that use the key are performed.
        A protection mode of `HSM` means that the key persists on a hardware security module (HSM) and all cryptographic operations are performed inside
        the HSM. A protection mode of `SOFTWARE` means that the key persists on the server, protected by the vault's RSA wrapping key which persists
        on the HSM. All cryptographic operations that use a key with a protection mode of `SOFTWARE` are performed on the server. By default,
        a key's protection mode is set to `HSM`. You can't change a key's protection mode after the key is created or imported.

        Allowed values for this property are: "HSM", "SOFTWARE"


        :return: The protection_mode of this CreateKeyDetails.
        :rtype: str
        """
        return self._protection_mode

    @protection_mode.setter
    def protection_mode(self, protection_mode):
        """
        Sets the protection_mode of this CreateKeyDetails.
        The key's protection mode indicates how the key persists and where cryptographic operations that use the key are performed.
        A protection mode of `HSM` means that the key persists on a hardware security module (HSM) and all cryptographic operations are performed inside
        the HSM. A protection mode of `SOFTWARE` means that the key persists on the server, protected by the vault's RSA wrapping key which persists
        on the HSM. All cryptographic operations that use a key with a protection mode of `SOFTWARE` are performed on the server. By default,
        a key's protection mode is set to `HSM`. You can't change a key's protection mode after the key is created or imported.


        :param protection_mode: The protection_mode of this CreateKeyDetails.
        :type: str
        """
        allowed_values = ["HSM", "SOFTWARE"]
        if not value_allowed_none_or_none_sentinel(protection_mode, allowed_values):
            raise ValueError(
                "Invalid value for `protection_mode`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._protection_mode = protection_mode

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_zone_base_details import CreateZoneBaseDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateZoneDetails(CreateZoneBaseDetails):
    """
    The body for defining a new zone.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the zone_type property of a CreateZoneDetails.
    #: This constant has a value of "PRIMARY"
    ZONE_TYPE_PRIMARY = "PRIMARY"

    #: A constant which can be used with the zone_type property of a CreateZoneDetails.
    #: This constant has a value of "SECONDARY"
    ZONE_TYPE_SECONDARY = "SECONDARY"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateZoneDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.dns.models.CreateZoneDetails.migration_source` attribute
        of this class is ``NONE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param migration_source:
            The value to assign to the migration_source property of this CreateZoneDetails.
            Allowed values for this property are: "NONE", "DYNECT"
        :type migration_source: str

        :param name:
            The value to assign to the name property of this CreateZoneDetails.
        :type name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateZoneDetails.
        :type compartment_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateZoneDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateZoneDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param zone_type:
            The value to assign to the zone_type property of this CreateZoneDetails.
            Allowed values for this property are: "PRIMARY", "SECONDARY"
        :type zone_type: str

        :param external_masters:
            The value to assign to the external_masters property of this CreateZoneDetails.
        :type external_masters: list[ExternalMaster]

        """
        self.swagger_types = {
            'migration_source': 'str',
            'name': 'str',
            'compartment_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'zone_type': 'str',
            'external_masters': 'list[ExternalMaster]'
        }

        self.attribute_map = {
            'migration_source': 'migrationSource',
            'name': 'name',
            'compartment_id': 'compartmentId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'zone_type': 'zoneType',
            'external_masters': 'externalMasters'
        }

        self._migration_source = None
        self._name = None
        self._compartment_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._zone_type = None
        self._external_masters = None
        self._migration_source = 'NONE'

    @property
    def zone_type(self):
        """
        Gets the zone_type of this CreateZoneDetails.
        The type of the zone. Must be either `PRIMARY` or `SECONDARY`.

        Allowed values for this property are: "PRIMARY", "SECONDARY"


        :return: The zone_type of this CreateZoneDetails.
        :rtype: str
        """
        return self._zone_type

    @zone_type.setter
    def zone_type(self, zone_type):
        """
        Sets the zone_type of this CreateZoneDetails.
        The type of the zone. Must be either `PRIMARY` or `SECONDARY`.


        :param zone_type: The zone_type of this CreateZoneDetails.
        :type: str
        """
        allowed_values = ["PRIMARY", "SECONDARY"]
        if not value_allowed_none_or_none_sentinel(zone_type, allowed_values):
            raise ValueError(
                "Invalid value for `zone_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._zone_type = zone_type

    @property
    def external_masters(self):
        """
        Gets the external_masters of this CreateZoneDetails.
        External master servers for the zone. `externalMasters` becomes a
        required parameter when the `zoneType` value is `SECONDARY`.


        :return: The external_masters of this CreateZoneDetails.
        :rtype: list[ExternalMaster]
        """
        return self._external_masters

    @external_masters.setter
    def external_masters(self, external_masters):
        """
        Sets the external_masters of this CreateZoneDetails.
        External master servers for the zone. `externalMasters` becomes a
        required parameter when the `zoneType` value is `SECONDARY`.


        :param external_masters: The external_masters of this CreateZoneDetails.
        :type: list[ExternalMaster]
        """
        self._external_masters = external_masters

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .add_image_shape_compatibility_entry_details import AddImageShapeCompatibilityEntryDetails
from .add_network_security_group_security_rules_details import AddNetworkSecurityGroupSecurityRulesDetails
from .add_public_ip_pool_capacity_details import AddPublicIpPoolCapacityDetails
from .add_security_rule_details import AddSecurityRuleDetails
from .added_network_security_group_security_rules import AddedNetworkSecurityGroupSecurityRules
from .app_catalog_listing import AppCatalogListing
from .app_catalog_listing_resource_version import AppCatalogListingResourceVersion
from .app_catalog_listing_resource_version_agreements import AppCatalogListingResourceVersionAgreements
from .app_catalog_listing_resource_version_summary import AppCatalogListingResourceVersionSummary
from .app_catalog_listing_summary import AppCatalogListingSummary
from .app_catalog_subscription import AppCatalogSubscription
from .app_catalog_subscription_summary import AppCatalogSubscriptionSummary
from .attach_boot_volume_details import AttachBootVolumeDetails
from .attach_emulated_volume_details import AttachEmulatedVolumeDetails
from .attach_i_scsi_volume_details import AttachIScsiVolumeDetails
from .attach_load_balancer_details import AttachLoadBalancerDetails
from .attach_paravirtualized_volume_details import AttachParavirtualizedVolumeDetails
from .attach_service_determined_volume_details import AttachServiceDeterminedVolumeDetails
from .attach_vnic_details import AttachVnicDetails
from .attach_volume_details import AttachVolumeDetails
from .bgp_session_info import BgpSessionInfo
from .boolean_image_capability_schema_descriptor import BooleanImageCapabilitySchemaDescriptor
from .boot_volume import BootVolume
from .boot_volume_attachment import BootVolumeAttachment
from .boot_volume_backup import BootVolumeBackup
from .boot_volume_kms_key import BootVolumeKmsKey
from .boot_volume_source_details import BootVolumeSourceDetails
from .boot_volume_source_from_boot_volume_backup_details import BootVolumeSourceFromBootVolumeBackupDetails
from .boot_volume_source_from_boot_volume_details import BootVolumeSourceFromBootVolumeDetails
from .bulk_add_virtual_circuit_public_prefixes_details import BulkAddVirtualCircuitPublicPrefixesDetails
from .bulk_delete_virtual_circuit_public_prefixes_details import BulkDeleteVirtualCircuitPublicPrefixesDetails
from .byoip_allocated_range_collection import ByoipAllocatedRangeCollection
from .byoip_allocated_range_summary import ByoipAllocatedRangeSummary
from .byoip_range import ByoipRange
from .byoip_range_collection import ByoipRangeCollection
from .byoip_range_summary import ByoipRangeSummary
from .capture_console_history_details import CaptureConsoleHistoryDetails
from .change_boot_volume_backup_compartment_details import ChangeBootVolumeBackupCompartmentDetails
from .change_boot_volume_compartment_details import ChangeBootVolumeCompartmentDetails
from .change_byoip_range_compartment_details import ChangeByoipRangeCompartmentDetails
from .change_cluster_network_compartment_details import ChangeClusterNetworkCompartmentDetails
from .change_compute_image_capability_schema_compartment_details import ChangeComputeImageCapabilitySchemaCompartmentDetails
from .change_cpe_compartment_details import ChangeCpeCompartmentDetails
from .change_cross_connect_compartment_details import ChangeCrossConnectCompartmentDetails
from .change_cross_connect_group_compartment_details import ChangeCrossConnectGroupCompartmentDetails
from .change_dedicated_vm_host_compartment_details import ChangeDedicatedVmHostCompartmentDetails
from .change_dhcp_options_compartment_details import ChangeDhcpOptionsCompartmentDetails
from .change_drg_compartment_details import ChangeDrgCompartmentDetails
from .change_ip_sec_connection_compartment_details import ChangeIPSecConnectionCompartmentDetails
from .change_image_compartment_details import ChangeImageCompartmentDetails
from .change_instance_compartment_details import ChangeInstanceCompartmentDetails
from .change_instance_configuration_compartment_details import ChangeInstanceConfigurationCompartmentDetails
from .change_instance_pool_compartment_details import ChangeInstancePoolCompartmentDetails
from .change_internet_gateway_compartment_details import ChangeInternetGatewayCompartmentDetails
from .change_local_peering_gateway_compartment_details import ChangeLocalPeeringGatewayCompartmentDetails
from .change_nat_gateway_compartment_details import ChangeNatGatewayCompartmentDetails
from .change_network_security_group_compartment_details import ChangeNetworkSecurityGroupCompartmentDetails
from .change_public_ip_compartment_details import ChangePublicIpCompartmentDetails
from .change_public_ip_pool_compartment_details import ChangePublicIpPoolCompartmentDetails
from .change_remote_peering_connection_compartment_details import ChangeRemotePeeringConnectionCompartmentDetails
from .change_route_table_compartment_details import ChangeRouteTableCompartmentDetails
from .change_security_list_compartment_details import ChangeSecurityListCompartmentDetails
from .change_service_gateway_compartment_details import ChangeServiceGatewayCompartmentDetails
from .change_subnet_compartment_details import ChangeSubnetCompartmentDetails
from .change_vcn_compartment_details import ChangeVcnCompartmentDetails
from .change_virtual_circuit_compartment_details import ChangeVirtualCircuitCompartmentDetails
from .change_vlan_compartment_details import ChangeVlanCompartmentDetails
from .change_volume_backup_compartment_details import ChangeVolumeBackupCompartmentDetails
from .change_volume_compartment_details import ChangeVolumeCompartmentDetails
from .change_volume_group_backup_compartment_details import ChangeVolumeGroupBackupCompartmentDetails
from .change_volume_group_compartment_details import ChangeVolumeGroupCompartmentDetails
from .cluster_network import ClusterNetwork
from .cluster_network_placement_configuration_details import ClusterNetworkPlacementConfigurationDetails
from .cluster_network_summary import ClusterNetworkSummary
from .compute_global_image_capability_schema import ComputeGlobalImageCapabilitySchema
from .compute_global_image_capability_schema_summary import ComputeGlobalImageCapabilitySchemaSummary
from .compute_global_image_capability_schema_version import ComputeGlobalImageCapabilitySchemaVersion
from .compute_global_image_capability_schema_version_summary import ComputeGlobalImageCapabilitySchemaVersionSummary
from .compute_image_capability_schema import ComputeImageCapabilitySchema
from .compute_image_capability_schema_summary import ComputeImageCapabilitySchemaSummary
from .compute_instance_details import ComputeInstanceDetails
from .connect_local_peering_gateways_details import ConnectLocalPeeringGatewaysDetails
from .connect_remote_peering_connections_details import ConnectRemotePeeringConnectionsDetails
from .console_history import ConsoleHistory
from .copy_boot_volume_backup_details import CopyBootVolumeBackupDetails
from .copy_volume_backup_details import CopyVolumeBackupDetails
from .cpe import Cpe
from .cpe_device_config_answer import CpeDeviceConfigAnswer
from .cpe_device_config_question import CpeDeviceConfigQuestion
from .cpe_device_info import CpeDeviceInfo
from .cpe_device_shape_detail import CpeDeviceShapeDetail
from .cpe_device_shape_summary import CpeDeviceShapeSummary
from .create_app_catalog_subscription_details import CreateAppCatalogSubscriptionDetails
from .create_boot_volume_backup_details import CreateBootVolumeBackupDetails
from .create_boot_volume_details import CreateBootVolumeDetails
from .create_byoip_range_details import CreateByoipRangeDetails
from .create_cluster_network_details import CreateClusterNetworkDetails
from .create_cluster_network_instance_pool_details import CreateClusterNetworkInstancePoolDetails
from .create_compute_image_capability_schema_details import CreateComputeImageCapabilitySchemaDetails
from .create_cpe_details import CreateCpeDetails
from .create_cross_connect_details import CreateCrossConnectDetails
from .create_cross_connect_group_details import CreateCrossConnectGroupDetails
from .create_dedicated_vm_host_details import CreateDedicatedVmHostDetails
from .create_dhcp_details import CreateDhcpDetails
from .create_drg_attachment_details import CreateDrgAttachmentDetails
from .create_drg_details import CreateDrgDetails
from .create_ip_sec_connection_details import CreateIPSecConnectionDetails
from .create_ip_sec_connection_tunnel_details import CreateIPSecConnectionTunnelDetails
from .create_ip_sec_tunnel_bgp_session_details import CreateIPSecTunnelBgpSessionDetails
from .create_image_details import CreateImageDetails
from .create_instance_configuration_base import CreateInstanceConfigurationBase
from .create_instance_configuration_details import CreateInstanceConfigurationDetails
from .create_instance_configuration_from_instance_details import CreateInstanceConfigurationFromInstanceDetails
from .create_instance_console_connection_details import CreateInstanceConsoleConnectionDetails
from .create_instance_pool_details import CreateInstancePoolDetails
from .create_instance_pool_placement_configuration_details import CreateInstancePoolPlacementConfigurationDetails
from .create_internet_gateway_details import CreateInternetGatewayDetails
from .create_ipv6_details import CreateIpv6Details
from .create_local_peering_gateway_details import CreateLocalPeeringGatewayDetails
from .create_nat_gateway_details import CreateNatGatewayDetails
from .create_network_security_group_details import CreateNetworkSecurityGroupDetails
from .create_private_ip_details import CreatePrivateIpDetails
from .create_public_ip_details import CreatePublicIpDetails
from .create_public_ip_pool_details import CreatePublicIpPoolDetails
from .create_remote_peering_connection_details import CreateRemotePeeringConnectionDetails
from .create_route_table_details import CreateRouteTableDetails
from .create_security_list_details import CreateSecurityListDetails
from .create_service_gateway_details import CreateServiceGatewayDetails
from .create_subnet_details import CreateSubnetDetails
from .create_vcn_details import CreateVcnDetails
from .create_virtual_circuit_details import CreateVirtualCircuitDetails
from .create_virtual_circuit_public_prefix_details import CreateVirtualCircuitPublicPrefixDetails
from .create_vlan_details import CreateVlanDetails
from .create_vnic_details import CreateVnicDetails
from .create_volume_backup_details import CreateVolumeBackupDetails
from .create_volume_backup_policy_assignment_details import CreateVolumeBackupPolicyAssignmentDetails
from .create_volume_backup_policy_details import CreateVolumeBackupPolicyDetails
from .create_volume_details import CreateVolumeDetails
from .create_volume_group_backup_details import CreateVolumeGroupBackupDetails
from .create_volume_group_details import CreateVolumeGroupDetails
from .cross_connect import CrossConnect
from .cross_connect_group import CrossConnectGroup
from .cross_connect_location import CrossConnectLocation
from .cross_connect_mapping import CrossConnectMapping
from .cross_connect_port_speed_shape import CrossConnectPortSpeedShape
from .cross_connect_status import CrossConnectStatus
from .dedicated_vm_host import DedicatedVmHost
from .dedicated_vm_host_instance_shape_summary import DedicatedVmHostInstanceShapeSummary
from .dedicated_vm_host_instance_summary import DedicatedVmHostInstanceSummary
from .dedicated_vm_host_shape_summary import DedicatedVmHostShapeSummary
from .dedicated_vm_host_summary import DedicatedVmHostSummary
from .delete_virtual_circuit_public_prefix_details import DeleteVirtualCircuitPublicPrefixDetails
from .detach_load_balancer_details import DetachLoadBalancerDetails
from .device import Device
from .dhcp_dns_option import DhcpDnsOption
from .dhcp_option import DhcpOption
from .dhcp_options import DhcpOptions
from .dhcp_search_domain_option import DhcpSearchDomainOption
from .drg import Drg
from .drg_attachment import DrgAttachment
from .drg_redundancy_status import DrgRedundancyStatus
from .egress_security_rule import EgressSecurityRule
from .emulated_volume_attachment import EmulatedVolumeAttachment
from .enum_integer_image_capability_descriptor import EnumIntegerImageCapabilityDescriptor
from .enum_string_image_capability_schema_descriptor import EnumStringImageCapabilitySchemaDescriptor
from .export_image_details import ExportImageDetails
from .export_image_via_object_storage_tuple_details import ExportImageViaObjectStorageTupleDetails
from .export_image_via_object_storage_uri_details import ExportImageViaObjectStorageUriDetails
from .fast_connect_provider_service import FastConnectProviderService
from .fast_connect_provider_service_key import FastConnectProviderServiceKey
from .get_public_ip_by_ip_address_details import GetPublicIpByIpAddressDetails
from .get_public_ip_by_private_ip_id_details import GetPublicIpByPrivateIpIdDetails
from .ip_sec_connection import IPSecConnection
from .ip_sec_connection_device_config import IPSecConnectionDeviceConfig
from .ip_sec_connection_device_status import IPSecConnectionDeviceStatus
from .ip_sec_connection_tunnel import IPSecConnectionTunnel
from .ip_sec_connection_tunnel_shared_secret import IPSecConnectionTunnelSharedSecret
from .i_scsi_volume_attachment import IScsiVolumeAttachment
from .icmp_options import IcmpOptions
from .image import Image
from .image_capability_schema_descriptor import ImageCapabilitySchemaDescriptor
from .image_memory_constraints import ImageMemoryConstraints
from .image_ocpu_constraints import ImageOcpuConstraints
from .image_shape_compatibility_entry import ImageShapeCompatibilityEntry
from .image_shape_compatibility_summary import ImageShapeCompatibilitySummary
from .image_source_details import ImageSourceDetails
from .image_source_via_object_storage_tuple_details import ImageSourceViaObjectStorageTupleDetails
from .image_source_via_object_storage_uri_details import ImageSourceViaObjectStorageUriDetails
from .ingress_security_rule import IngressSecurityRule
from .instance import Instance
from .instance_agent_config import InstanceAgentConfig
from .instance_agent_features import InstanceAgentFeatures
from .instance_availability_config import InstanceAvailabilityConfig
from .instance_configuration import InstanceConfiguration
from .instance_configuration_attach_vnic_details import InstanceConfigurationAttachVnicDetails
from .instance_configuration_attach_volume_details import InstanceConfigurationAttachVolumeDetails
from .instance_configuration_availability_config import InstanceConfigurationAvailabilityConfig
from .instance_configuration_block_volume_details import InstanceConfigurationBlockVolumeDetails
from .instance_configuration_create_vnic_details import InstanceConfigurationCreateVnicDetails
from .instance_configuration_create_volume_details import InstanceConfigurationCreateVolumeDetails
from .instance_configuration_instance_details import InstanceConfigurationInstanceDetails
from .instance_configuration_instance_source_details import InstanceConfigurationInstanceSourceDetails
from .instance_configuration_instance_source_via_boot_volume_details import InstanceConfigurationInstanceSourceViaBootVolumeDetails
from .instance_configuration_instance_source_via_image_details import InstanceConfigurationInstanceSourceViaImageDetails
from .instance_configuration_iscsi_attach_volume_details import InstanceConfigurationIscsiAttachVolumeDetails
from .instance_configuration_launch_instance_agent_config_details import InstanceConfigurationLaunchInstanceAgentConfigDetails
from .instance_configuration_launch_instance_details import InstanceConfigurationLaunchInstanceDetails
from .instance_configuration_launch_instance_shape_config_details import InstanceConfigurationLaunchInstanceShapeConfigDetails
from .instance_configuration_launch_options import InstanceConfigurationLaunchOptions
from .instance_configuration_paravirtualized_attach_volume_details import InstanceConfigurationParavirtualizedAttachVolumeDetails
from .instance_configuration_summary import InstanceConfigurationSummary
from .instance_configuration_volume_source_details import InstanceConfigurationVolumeSourceDetails
from .instance_configuration_volume_source_from_volume_backup_details import InstanceConfigurationVolumeSourceFromVolumeBackupDetails
from .instance_configuration_volume_source_from_volume_details import InstanceConfigurationVolumeSourceFromVolumeDetails
from .instance_console_connection import InstanceConsoleConnection
from .instance_credentials import InstanceCredentials
from .instance_pool import InstancePool
from .instance_pool_instance_load_balancer_backend import InstancePoolInstanceLoadBalancerBackend
from .instance_pool_load_balancer_attachment import InstancePoolLoadBalancerAttachment
from .instance_pool_placement_configuration import InstancePoolPlacementConfiguration
from .instance_pool_placement_secondary_vnic_subnet import InstancePoolPlacementSecondaryVnicSubnet
from .instance_pool_summary import InstancePoolSummary
from .instance_shape_config import InstanceShapeConfig
from .instance_source_details import InstanceSourceDetails
from .instance_source_via_boot_volume_details import InstanceSourceViaBootVolumeDetails
from .instance_source_via_image_details import InstanceSourceViaImageDetails
from .instance_summary import InstanceSummary
from .internet_gateway import InternetGateway
from .ipv6 import Ipv6
from .launch_instance_agent_config_details import LaunchInstanceAgentConfigDetails
from .launch_instance_availability_config_details import LaunchInstanceAvailabilityConfigDetails
from .launch_instance_details import LaunchInstanceDetails
from .launch_instance_shape_config_details import LaunchInstanceShapeConfigDetails
from .launch_options import LaunchOptions
from .letter_of_authority import LetterOfAuthority
from .local_peering_gateway import LocalPeeringGateway
from .nat_gateway import NatGateway
from .network_security_group import NetworkSecurityGroup
from .network_security_group_vnic import NetworkSecurityGroupVnic
from .paravirtualized_volume_attachment import ParavirtualizedVolumeAttachment
from .peer_region_for_remote_peering import PeerRegionForRemotePeering
from .port_range import PortRange
from .private_ip import PrivateIp
from .public_ip import PublicIp
from .public_ip_pool import PublicIpPool
from .public_ip_pool_collection import PublicIpPoolCollection
from .public_ip_pool_summary import PublicIpPoolSummary
from .remote_peering_connection import RemotePeeringConnection
from .remove_network_security_group_security_rules_details import RemoveNetworkSecurityGroupSecurityRulesDetails
from .remove_public_ip_pool_capacity_details import RemovePublicIpPoolCapacityDetails
from .route_rule import RouteRule
from .route_table import RouteTable
from .security_list import SecurityList
from .security_rule import SecurityRule
from .service import Service
from .service_gateway import ServiceGateway
from .service_id_request_details import ServiceIdRequestDetails
from .service_id_response_details import ServiceIdResponseDetails
from .shape import Shape
from .shape_max_vnic_attachment_options import ShapeMaxVnicAttachmentOptions
from .shape_memory_options import ShapeMemoryOptions
from .shape_networking_bandwidth_options import ShapeNetworkingBandwidthOptions
from .shape_ocpu_options import ShapeOcpuOptions
from .subnet import Subnet
from .tcp_options import TcpOptions
from .tunnel_config import TunnelConfig
from .tunnel_cpe_device_config import TunnelCpeDeviceConfig
from .tunnel_status import TunnelStatus
from .udp_options import UdpOptions
from .update_boot_volume_backup_details import UpdateBootVolumeBackupDetails
from .update_boot_volume_details import UpdateBootVolumeDetails
from .update_boot_volume_kms_key_details import UpdateBootVolumeKmsKeyDetails
from .update_byoip_range_details import UpdateByoipRangeDetails
from .update_cluster_network_details import UpdateClusterNetworkDetails
from .update_compute_image_capability_schema_details import UpdateComputeImageCapabilitySchemaDetails
from .update_console_history_details import UpdateConsoleHistoryDetails
from .update_cpe_details import UpdateCpeDetails
from .update_cross_connect_details import UpdateCrossConnectDetails
from .update_cross_connect_group_details import UpdateCrossConnectGroupDetails
from .update_dedicated_vm_host_details import UpdateDedicatedVmHostDetails
from .update_dhcp_details import UpdateDhcpDetails
from .update_drg_attachment_details import UpdateDrgAttachmentDetails
from .update_drg_details import UpdateDrgDetails
from .update_ip_sec_connection_details import UpdateIPSecConnectionDetails
from .update_ip_sec_connection_tunnel_details import UpdateIPSecConnectionTunnelDetails
from .update_ip_sec_connection_tunnel_shared_secret_details import UpdateIPSecConnectionTunnelSharedSecretDetails
from .update_ip_sec_tunnel_bgp_session_details import UpdateIPSecTunnelBgpSessionDetails
from .update_image_details import UpdateImageDetails
from .update_instance_agent_config_details import UpdateInstanceAgentConfigDetails
from .update_instance_availability_config_details import UpdateInstanceAvailabilityConfigDetails
from .update_instance_configuration_details import UpdateInstanceConfigurationDetails
from .update_instance_console_connection_details import UpdateInstanceConsoleConnectionDetails
from .update_instance_details import UpdateInstanceDetails
from .update_instance_pool_details import UpdateInstancePoolDetails
from .update_instance_pool_placement_configuration_details import UpdateInstancePoolPlacementConfigurationDetails
from .update_instance_shape_config_details import UpdateInstanceShapeConfigDetails
from .update_internet_gateway_details import UpdateInternetGatewayDetails
from .update_ipv6_details import UpdateIpv6Details
from .update_launch_options import UpdateLaunchOptions
from .update_local_peering_gateway_details import UpdateLocalPeeringGatewayDetails
from .update_nat_gateway_details import UpdateNatGatewayDetails
from .update_network_security_group_details import UpdateNetworkSecurityGroupDetails
from .update_network_security_group_security_rules_details import UpdateNetworkSecurityGroupSecurityRulesDetails
from .update_private_ip_details import UpdatePrivateIpDetails
from .update_public_ip_details import UpdatePublicIpDetails
from .update_public_ip_pool_details import UpdatePublicIpPoolDetails
from .update_remote_peering_connection_details import UpdateRemotePeeringConnectionDetails
from .update_route_table_details import UpdateRouteTableDetails
from .update_security_list_details import UpdateSecurityListDetails
from .update_security_rule_details import UpdateSecurityRuleDetails
from .update_service_gateway_details import UpdateServiceGatewayDetails
from .update_subnet_details import UpdateSubnetDetails
from .update_tunnel_cpe_device_config_details import UpdateTunnelCpeDeviceConfigDetails
from .update_vcn_details import UpdateVcnDetails
from .update_virtual_circuit_details import UpdateVirtualCircuitDetails
from .update_vlan_details import UpdateVlanDetails
from .update_vnic_details import UpdateVnicDetails
from .update_volume_backup_details import UpdateVolumeBackupDetails
from .update_volume_backup_policy_details import UpdateVolumeBackupPolicyDetails
from .update_volume_details import UpdateVolumeDetails
from .update_volume_group_backup_details import UpdateVolumeGroupBackupDetails
from .update_volume_group_details import UpdateVolumeGroupDetails
from .update_volume_kms_key_details import UpdateVolumeKmsKeyDetails
from .updated_network_security_group_security_rules import UpdatedNetworkSecurityGroupSecurityRules
from .vcn import Vcn
from .virtual_circuit import VirtualCircuit
from .virtual_circuit_bandwidth_shape import VirtualCircuitBandwidthShape
from .virtual_circuit_public_prefix import VirtualCircuitPublicPrefix
from .vlan import Vlan
from .vnic import Vnic
from .vnic_attachment import VnicAttachment
from .volume import Volume
from .volume_attachment import VolumeAttachment
from .volume_backup import VolumeBackup
from .volume_backup_policy import VolumeBackupPolicy
from .volume_backup_policy_assignment import VolumeBackupPolicyAssignment
from .volume_backup_schedule import VolumeBackupSchedule
from .volume_group import VolumeGroup
from .volume_group_backup import VolumeGroupBackup
from .volume_group_source_details import VolumeGroupSourceDetails
from .volume_group_source_from_volume_group_backup_details import VolumeGroupSourceFromVolumeGroupBackupDetails
from .volume_group_source_from_volume_group_details import VolumeGroupSourceFromVolumeGroupDetails
from .volume_group_source_from_volumes_details import VolumeGroupSourceFromVolumesDetails
from .volume_kms_key import VolumeKmsKey
from .volume_source_details import VolumeSourceDetails
from .volume_source_from_volume_backup_details import VolumeSourceFromVolumeBackupDetails
from .volume_source_from_volume_details import VolumeSourceFromVolumeDetails

# Maps type names to classes for core services.
core_type_mapping = {
    "AddImageShapeCompatibilityEntryDetails": AddImageShapeCompatibilityEntryDetails,
    "AddNetworkSecurityGroupSecurityRulesDetails": AddNetworkSecurityGroupSecurityRulesDetails,
    "AddPublicIpPoolCapacityDetails": AddPublicIpPoolCapacityDetails,
    "AddSecurityRuleDetails": AddSecurityRuleDetails,
    "AddedNetworkSecurityGroupSecurityRules": AddedNetworkSecurityGroupSecurityRules,
    "AppCatalogListing": AppCatalogListing,
    "AppCatalogListingResourceVersion": AppCatalogListingResourceVersion,
    "AppCatalogListingResourceVersionAgreements": AppCatalogListingResourceVersionAgreements,
    "AppCatalogListingResourceVersionSummary": AppCatalogListingResourceVersionSummary,
    "AppCatalogListingSummary": AppCatalogListingSummary,
    "AppCatalogSubscription": AppCatalogSubscription,
    "AppCatalogSubscriptionSummary": AppCatalogSubscriptionSummary,
    "AttachBootVolumeDetails": AttachBootVolumeDetails,
    "AttachEmulatedVolumeDetails": AttachEmulatedVolumeDetails,
    "AttachIScsiVolumeDetails": AttachIScsiVolumeDetails,
    "AttachLoadBalancerDetails": AttachLoadBalancerDetails,
    "AttachParavirtualizedVolumeDetails": AttachParavirtualizedVolumeDetails,
    "AttachServiceDeterminedVolumeDetails": AttachServiceDeterminedVolumeDetails,
    "AttachVnicDetails": AttachVnicDetails,
    "AttachVolumeDetails": AttachVolumeDetails,
    "BgpSessionInfo": BgpSessionInfo,
    "BooleanImageCapabilitySchemaDescriptor": BooleanImageCapabilitySchemaDescriptor,
    "BootVolume": BootVolume,
    "BootVolumeAttachment": BootVolumeAttachment,
    "BootVolumeBackup": BootVolumeBackup,
    "BootVolumeKmsKey": BootVolumeKmsKey,
    "BootVolumeSourceDetails": BootVolumeSourceDetails,
    "BootVolumeSourceFromBootVolumeBackupDetails": BootVolumeSourceFromBootVolumeBackupDetails,
    "BootVolumeSourceFromBootVolumeDetails": BootVolumeSourceFromBootVolumeDetails,
    "BulkAddVirtualCircuitPublicPrefixesDetails": BulkAddVirtualCircuitPublicPrefixesDetails,
    "BulkDeleteVirtualCircuitPublicPrefixesDetails": BulkDeleteVirtualCircuitPublicPrefixesDetails,
    "ByoipAllocatedRangeCollection": ByoipAllocatedRangeCollection,
    "ByoipAllocatedRangeSummary": ByoipAllocatedRangeSummary,
    "ByoipRange": ByoipRange,
    "ByoipRangeCollection": ByoipRangeCollection,
    "ByoipRangeSummary": ByoipRangeSummary,
    "CaptureConsoleHistoryDetails": CaptureConsoleHistoryDetails,
    "ChangeBootVolumeBackupCompartmentDetails": ChangeBootVolumeBackupCompartmentDetails,
    "ChangeBootVolumeCompartmentDetails": ChangeBootVolumeCompartmentDetails,
    "ChangeByoipRangeCompartmentDetails": ChangeByoipRangeCompartmentDetails,
    "ChangeClusterNetworkCompartmentDetails": ChangeClusterNetworkCompartmentDetails,
    "ChangeComputeImageCapabilitySchemaCompartmentDetails": ChangeComputeImageCapabilitySchemaCompartmentDetails,
    "ChangeCpeCompartmentDetails": ChangeCpeCompartmentDetails,
    "ChangeCrossConnectCompartmentDetails": ChangeCrossConnectCompartmentDetails,
    "ChangeCrossConnectGroupCompartmentDetails": ChangeCrossConnectGroupCompartmentDetails,
    "ChangeDedicatedVmHostCompartmentDetails": ChangeDedicatedVmHostCompartmentDetails,
    "ChangeDhcpOptionsCompartmentDetails": ChangeDhcpOptionsCompartmentDetails,
    "ChangeDrgCompartmentDetails": ChangeDrgCompartmentDetails,
    "ChangeIPSecConnectionCompartmentDetails": ChangeIPSecConnectionCompartmentDetails,
    "ChangeImageCompartmentDetails": ChangeImageCompartmentDetails,
    "ChangeInstanceCompartmentDetails": ChangeInstanceCompartmentDetails,
    "ChangeInstanceConfigurationCompartmentDetails": ChangeInstanceConfigurationCompartmentDetails,
    "ChangeInstancePoolCompartmentDetails": ChangeInstancePoolCompartmentDetails,
    "ChangeInternetGatewayCompartmentDetails": ChangeInternetGatewayCompartmentDetails,
    "ChangeLocalPeeringGatewayCompartmentDetails": ChangeLocalPeeringGatewayCompartmentDetails,
    "ChangeNatGatewayCompartmentDetails": ChangeNatGatewayCompartmentDetails,
    "ChangeNetworkSecurityGroupCompartmentDetails": ChangeNetworkSecurityGroupCompartmentDetails,
    "ChangePublicIpCompartmentDetails": ChangePublicIpCompartmentDetails,
    "ChangePublicIpPoolCompartmentDetails": ChangePublicIpPoolCompartmentDetails,
    "ChangeRemotePeeringConnectionCompartmentDetails": ChangeRemotePeeringConnectionCompartmentDetails,
    "ChangeRouteTableCompartmentDetails": ChangeRouteTableCompartmentDetails,
    "ChangeSecurityListCompartmentDetails": ChangeSecurityListCompartmentDetails,
    "ChangeServiceGatewayCompartmentDetails": ChangeServiceGatewayCompartmentDetails,
    "ChangeSubnetCompartmentDetails": ChangeSubnetCompartmentDetails,
    "ChangeVcnCompartmentDetails": ChangeVcnCompartmentDetails,
    "ChangeVirtualCircuitCompartmentDetails": ChangeVirtualCircuitCompartmentDetails,
    "ChangeVlanCompartmentDetails": ChangeVlanCompartmentDetails,
    "ChangeVolumeBackupCompartmentDetails": ChangeVolumeBackupCompartmentDetails,
    "ChangeVolumeCompartmentDetails": ChangeVolumeCompartmentDetails,
    "ChangeVolumeGroupBackupCompartmentDetails": ChangeVolumeGroupBackupCompartmentDetails,
    "ChangeVolumeGroupCompartmentDetails": ChangeVolumeGroupCompartmentDetails,
    "ClusterNetwork": ClusterNetwork,
    "ClusterNetworkPlacementConfigurationDetails": ClusterNetworkPlacementConfigurationDetails,
    "ClusterNetworkSummary": ClusterNetworkSummary,
    "ComputeGlobalImageCapabilitySchema": ComputeGlobalImageCapabilitySchema,
    "ComputeGlobalImageCapabilitySchemaSummary": ComputeGlobalImageCapabilitySchemaSummary,
    "ComputeGlobalImageCapabilitySchemaVersion": ComputeGlobalImageCapabilitySchemaVersion,
    "ComputeGlobalImageCapabilitySchemaVersionSummary": ComputeGlobalImageCapabilitySchemaVersionSummary,
    "ComputeImageCapabilitySchema": ComputeImageCapabilitySchema,
    "ComputeImageCapabilitySchemaSummary": ComputeImageCapabilitySchemaSummary,
    "ComputeInstanceDetails": ComputeInstanceDetails,
    "ConnectLocalPeeringGatewaysDetails": ConnectLocalPeeringGatewaysDetails,
    "ConnectRemotePeeringConnectionsDetails": ConnectRemotePeeringConnectionsDetails,
    "ConsoleHistory": ConsoleHistory,
    "CopyBootVolumeBackupDetails": CopyBootVolumeBackupDetails,
    "CopyVolumeBackupDetails": CopyVolumeBackupDetails,
    "Cpe": Cpe,
    "CpeDeviceConfigAnswer": CpeDeviceConfigAnswer,
    "CpeDeviceConfigQuestion": CpeDeviceConfigQuestion,
    "CpeDeviceInfo": CpeDeviceInfo,
    "CpeDeviceShapeDetail": CpeDeviceShapeDetail,
    "CpeDeviceShapeSummary": CpeDeviceShapeSummary,
    "CreateAppCatalogSubscriptionDetails": CreateAppCatalogSubscriptionDetails,
    "CreateBootVolumeBackupDetails": CreateBootVolumeBackupDetails,
    "CreateBootVolumeDetails": CreateBootVolumeDetails,
    "CreateByoipRangeDetails": CreateByoipRangeDetails,
    "CreateClusterNetworkDetails": CreateClusterNetworkDetails,
    "CreateClusterNetworkInstancePoolDetails": CreateClusterNetworkInstancePoolDetails,
    "CreateComputeImageCapabilitySchemaDetails": CreateComputeImageCapabilitySchemaDetails,
    "CreateCpeDetails": CreateCpeDetails,
    "CreateCrossConnectDetails": CreateCrossConnectDetails,
    "CreateCrossConnectGroupDetails": CreateCrossConnectGroupDetails,
    "CreateDedicatedVmHostDetails": CreateDedicatedVmHostDetails,
    "CreateDhcpDetails": CreateDhcpDetails,
    "CreateDrgAttachmentDetails": CreateDrgAttachmentDetails,
    "CreateDrgDetails": CreateDrgDetails,
    "CreateIPSecConnectionDetails": CreateIPSecConnectionDetails,
    "CreateIPSecConnectionTunnelDetails": CreateIPSecConnectionTunnelDetails,
    "CreateIPSecTunnelBgpSessionDetails": CreateIPSecTunnelBgpSessionDetails,
    "CreateImageDetails": CreateImageDetails,
    "CreateInstanceConfigurationBase": CreateInstanceConfigurationBase,
    "CreateInstanceConfigurationDetails": CreateInstanceConfigurationDetails,
    "CreateInstanceConfigurationFromInstanceDetails": CreateInstanceConfigurationFromInstanceDetails,
    "CreateInstanceConsoleConnectionDetails": CreateInstanceConsoleConnectionDetails,
    "CreateInstancePoolDetails": CreateInstancePoolDetails,
    "CreateInstancePoolPlacementConfigurationDetails": CreateInstancePoolPlacementConfigurationDetails,
    "CreateInternetGatewayDetails": CreateInternetGatewayDetails,
    "CreateIpv6Details": CreateIpv6Details,
    "CreateLocalPeeringGatewayDetails": CreateLocalPeeringGatewayDetails,
    "CreateNatGatewayDetails": CreateNatGatewayDetails,
    "CreateNetworkSecurityGroupDetails": CreateNetworkSecurityGroupDetails,
    "CreatePrivateIpDetails": CreatePrivateIpDetails,
    "CreatePublicIpDetails": CreatePublicIpDetails,
    "CreatePublicIpPoolDetails": CreatePublicIpPoolDetails,
    "CreateRemotePeeringConnectionDetails": CreateRemotePeeringConnectionDetails,
    "CreateRouteTableDetails": CreateRouteTableDetails,
    "CreateSecurityListDetails": CreateSecurityListDetails,
    "CreateServiceGatewayDetails": CreateServiceGatewayDetails,
    "CreateSubnetDetails": CreateSubnetDetails,
    "CreateVcnDetails": CreateVcnDetails,
    "CreateVirtualCircuitDetails": CreateVirtualCircuitDetails,
    "CreateVirtualCircuitPublicPrefixDetails": CreateVirtualCircuitPublicPrefixDetails,
    "CreateVlanDetails": CreateVlanDetails,
    "CreateVnicDetails": CreateVnicDetails,
    "CreateVolumeBackupDetails": CreateVolumeBackupDetails,
    "CreateVolumeBackupPolicyAssignmentDetails": CreateVolumeBackupPolicyAssignmentDetails,
    "CreateVolumeBackupPolicyDetails": CreateVolumeBackupPolicyDetails,
    "CreateVolumeDetails": CreateVolumeDetails,
    "CreateVolumeGroupBackupDetails": CreateVolumeGroupBackupDetails,
    "CreateVolumeGroupDetails": CreateVolumeGroupDetails,
    "CrossConnect": CrossConnect,
    "CrossConnectGroup": CrossConnectGroup,
    "CrossConnectLocation": CrossConnectLocation,
    "CrossConnectMapping": CrossConnectMapping,
    "CrossConnectPortSpeedShape": CrossConnectPortSpeedShape,
    "CrossConnectStatus": CrossConnectStatus,
    "DedicatedVmHost": DedicatedVmHost,
    "DedicatedVmHostInstanceShapeSummary": DedicatedVmHostInstanceShapeSummary,
    "DedicatedVmHostInstanceSummary": DedicatedVmHostInstanceSummary,
    "DedicatedVmHostShapeSummary": DedicatedVmHostShapeSummary,
    "DedicatedVmHostSummary": DedicatedVmHostSummary,
    "DeleteVirtualCircuitPublicPrefixDetails": DeleteVirtualCircuitPublicPrefixDetails,
    "DetachLoadBalancerDetails": DetachLoadBalancerDetails,
    "Device": Device,
    "DhcpDnsOption": DhcpDnsOption,
    "DhcpOption": DhcpOption,
    "DhcpOptions": DhcpOptions,
    "DhcpSearchDomainOption": DhcpSearchDomainOption,
    "Drg": Drg,
    "DrgAttachment": DrgAttachment,
    "DrgRedundancyStatus": DrgRedundancyStatus,
    "EgressSecurityRule": EgressSecurityRule,
    "EmulatedVolumeAttachment": EmulatedVolumeAttachment,
    "EnumIntegerImageCapabilityDescriptor": EnumIntegerImageCapabilityDescriptor,
    "EnumStringImageCapabilitySchemaDescriptor": EnumStringImageCapabilitySchemaDescriptor,
    "ExportImageDetails": ExportImageDetails,
    "ExportImageViaObjectStorageTupleDetails": ExportImageViaObjectStorageTupleDetails,
    "ExportImageViaObjectStorageUriDetails": ExportImageViaObjectStorageUriDetails,
    "FastConnectProviderService": FastConnectProviderService,
    "FastConnectProviderServiceKey": FastConnectProviderServiceKey,
    "GetPublicIpByIpAddressDetails": GetPublicIpByIpAddressDetails,
    "GetPublicIpByPrivateIpIdDetails": GetPublicIpByPrivateIpIdDetails,
    "IPSecConnection": IPSecConnection,
    "IPSecConnectionDeviceConfig": IPSecConnectionDeviceConfig,
    "IPSecConnectionDeviceStatus": IPSecConnectionDeviceStatus,
    "IPSecConnectionTunnel": IPSecConnectionTunnel,
    "IPSecConnectionTunnelSharedSecret": IPSecConnectionTunnelSharedSecret,
    "IScsiVolumeAttachment": IScsiVolumeAttachment,
    "IcmpOptions": IcmpOptions,
    "Image": Image,
    "ImageCapabilitySchemaDescriptor": ImageCapabilitySchemaDescriptor,
    "ImageMemoryConstraints": ImageMemoryConstraints,
    "ImageOcpuConstraints": ImageOcpuConstraints,
    "ImageShapeCompatibilityEntry": ImageShapeCompatibilityEntry,
    "ImageShapeCompatibilitySummary": ImageShapeCompatibilitySummary,
    "ImageSourceDetails": ImageSourceDetails,
    "ImageSourceViaObjectStorageTupleDetails": ImageSourceViaObjectStorageTupleDetails,
    "ImageSourceViaObjectStorageUriDetails": ImageSourceViaObjectStorageUriDetails,
    "IngressSecurityRule": IngressSecurityRule,
    "Instance": Instance,
    "InstanceAgentConfig": InstanceAgentConfig,
    "InstanceAgentFeatures": InstanceAgentFeatures,
    "InstanceAvailabilityConfig": InstanceAvailabilityConfig,
    "InstanceConfiguration": InstanceConfiguration,
    "InstanceConfigurationAttachVnicDetails": InstanceConfigurationAttachVnicDetails,
    "InstanceConfigurationAttachVolumeDetails": InstanceConfigurationAttachVolumeDetails,
    "InstanceConfigurationAvailabilityConfig": InstanceConfigurationAvailabilityConfig,
    "InstanceConfigurationBlockVolumeDetails": InstanceConfigurationBlockVolumeDetails,
    "InstanceConfigurationCreateVnicDetails": InstanceConfigurationCreateVnicDetails,
    "InstanceConfigurationCreateVolumeDetails": InstanceConfigurationCreateVolumeDetails,
    "InstanceConfigurationInstanceDetails": InstanceConfigurationInstanceDetails,
    "InstanceConfigurationInstanceSourceDetails": InstanceConfigurationInstanceSourceDetails,
    "InstanceConfigurationInstanceSourceViaBootVolumeDetails": InstanceConfigurationInstanceSourceViaBootVolumeDetails,
    "InstanceConfigurationInstanceSourceViaImageDetails": InstanceConfigurationInstanceSourceViaImageDetails,
    "InstanceConfigurationIscsiAttachVolumeDetails": InstanceConfigurationIscsiAttachVolumeDetails,
    "InstanceConfigurationLaunchInstanceAgentConfigDetails": InstanceConfigurationLaunchInstanceAgentConfigDetails,
    "InstanceConfigurationLaunchInstanceDetails": InstanceConfigurationLaunchInstanceDetails,
    "InstanceConfigurationLaunchInstanceShapeConfigDetails": InstanceConfigurationLaunchInstanceShapeConfigDetails,
    "InstanceConfigurationLaunchOptions": InstanceConfigurationLaunchOptions,
    "InstanceConfigurationParavirtualizedAttachVolumeDetails": InstanceConfigurationParavirtualizedAttachVolumeDetails,
    "InstanceConfigurationSummary": InstanceConfigurationSummary,
    "InstanceConfigurationVolumeSourceDetails": InstanceConfigurationVolumeSourceDetails,
    "InstanceConfigurationVolumeSourceFromVolumeBackupDetails": InstanceConfigurationVolumeSourceFromVolumeBackupDetails,
    "InstanceConfigurationVolumeSourceFromVolumeDetails": InstanceConfigurationVolumeSourceFromVolumeDetails,
    "InstanceConsoleConnection": InstanceConsoleConnection,
    "InstanceCredentials": InstanceCredentials,
    "InstancePool": InstancePool,
    "InstancePoolInstanceLoadBalancerBackend": InstancePoolInstanceLoadBalancerBackend,
    "InstancePoolLoadBalancerAttachment": InstancePoolLoadBalancerAttachment,
    "InstancePoolPlacementConfiguration": InstancePoolPlacementConfiguration,
    "InstancePoolPlacementSecondaryVnicSubnet": InstancePoolPlacementSecondaryVnicSubnet,
    "InstancePoolSummary": InstancePoolSummary,
    "InstanceShapeConfig": InstanceShapeConfig,
    "InstanceSourceDetails": InstanceSourceDetails,
    "InstanceSourceViaBootVolumeDetails": InstanceSourceViaBootVolumeDetails,
    "InstanceSourceViaImageDetails": InstanceSourceViaImageDetails,
    "InstanceSummary": InstanceSummary,
    "InternetGateway": InternetGateway,
    "Ipv6": Ipv6,
    "LaunchInstanceAgentConfigDetails": LaunchInstanceAgentConfigDetails,
    "LaunchInstanceAvailabilityConfigDetails": LaunchInstanceAvailabilityConfigDetails,
    "LaunchInstanceDetails": LaunchInstanceDetails,
    "LaunchInstanceShapeConfigDetails": LaunchInstanceShapeConfigDetails,
    "LaunchOptions": LaunchOptions,
    "LetterOfAuthority": LetterOfAuthority,
    "LocalPeeringGateway": LocalPeeringGateway,
    "NatGateway": NatGateway,
    "NetworkSecurityGroup": NetworkSecurityGroup,
    "NetworkSecurityGroupVnic": NetworkSecurityGroupVnic,
    "ParavirtualizedVolumeAttachment": ParavirtualizedVolumeAttachment,
    "PeerRegionForRemotePeering": PeerRegionForRemotePeering,
    "PortRange": PortRange,
    "PrivateIp": PrivateIp,
    "PublicIp": PublicIp,
    "PublicIpPool": PublicIpPool,
    "PublicIpPoolCollection": PublicIpPoolCollection,
    "PublicIpPoolSummary": PublicIpPoolSummary,
    "RemotePeeringConnection": RemotePeeringConnection,
    "RemoveNetworkSecurityGroupSecurityRulesDetails": RemoveNetworkSecurityGroupSecurityRulesDetails,
    "RemovePublicIpPoolCapacityDetails": RemovePublicIpPoolCapacityDetails,
    "RouteRule": RouteRule,
    "RouteTable": RouteTable,
    "SecurityList": SecurityList,
    "SecurityRule": SecurityRule,
    "Service": Service,
    "ServiceGateway": ServiceGateway,
    "ServiceIdRequestDetails": ServiceIdRequestDetails,
    "ServiceIdResponseDetails": ServiceIdResponseDetails,
    "Shape": Shape,
    "ShapeMaxVnicAttachmentOptions": ShapeMaxVnicAttachmentOptions,
    "ShapeMemoryOptions": ShapeMemoryOptions,
    "ShapeNetworkingBandwidthOptions": ShapeNetworkingBandwidthOptions,
    "ShapeOcpuOptions": ShapeOcpuOptions,
    "Subnet": Subnet,
    "TcpOptions": TcpOptions,
    "TunnelConfig": TunnelConfig,
    "TunnelCpeDeviceConfig": TunnelCpeDeviceConfig,
    "TunnelStatus": TunnelStatus,
    "UdpOptions": UdpOptions,
    "UpdateBootVolumeBackupDetails": UpdateBootVolumeBackupDetails,
    "UpdateBootVolumeDetails": UpdateBootVolumeDetails,
    "UpdateBootVolumeKmsKeyDetails": UpdateBootVolumeKmsKeyDetails,
    "UpdateByoipRangeDetails": UpdateByoipRangeDetails,
    "UpdateClusterNetworkDetails": UpdateClusterNetworkDetails,
    "UpdateComputeImageCapabilitySchemaDetails": UpdateComputeImageCapabilitySchemaDetails,
    "UpdateConsoleHistoryDetails": UpdateConsoleHistoryDetails,
    "UpdateCpeDetails": UpdateCpeDetails,
    "UpdateCrossConnectDetails": UpdateCrossConnectDetails,
    "UpdateCrossConnectGroupDetails": UpdateCrossConnectGroupDetails,
    "UpdateDedicatedVmHostDetails": UpdateDedicatedVmHostDetails,
    "UpdateDhcpDetails": UpdateDhcpDetails,
    "UpdateDrgAttachmentDetails": UpdateDrgAttachmentDetails,
    "UpdateDrgDetails": UpdateDrgDetails,
    "UpdateIPSecConnectionDetails": UpdateIPSecConnectionDetails,
    "UpdateIPSecConnectionTunnelDetails": UpdateIPSecConnectionTunnelDetails,
    "UpdateIPSecConnectionTunnelSharedSecretDetails": UpdateIPSecConnectionTunnelSharedSecretDetails,
    "UpdateIPSecTunnelBgpSessionDetails": UpdateIPSecTunnelBgpSessionDetails,
    "UpdateImageDetails": UpdateImageDetails,
    "UpdateInstanceAgentConfigDetails": UpdateInstanceAgentConfigDetails,
    "UpdateInstanceAvailabilityConfigDetails": UpdateInstanceAvailabilityConfigDetails,
    "UpdateInstanceConfigurationDetails": UpdateInstanceConfigurationDetails,
    "UpdateInstanceConsoleConnectionDetails": UpdateInstanceConsoleConnectionDetails,
    "UpdateInstanceDetails": UpdateInstanceDetails,
    "UpdateInstancePoolDetails": UpdateInstancePoolDetails,
    "UpdateInstancePoolPlacementConfigurationDetails": UpdateInstancePoolPlacementConfigurationDetails,
    "UpdateInstanceShapeConfigDetails": UpdateInstanceShapeConfigDetails,
    "UpdateInternetGatewayDetails": UpdateInternetGatewayDetails,
    "UpdateIpv6Details": UpdateIpv6Details,
    "UpdateLaunchOptions": UpdateLaunchOptions,
    "UpdateLocalPeeringGatewayDetails": UpdateLocalPeeringGatewayDetails,
    "UpdateNatGatewayDetails": UpdateNatGatewayDetails,
    "UpdateNetworkSecurityGroupDetails": UpdateNetworkSecurityGroupDetails,
    "UpdateNetworkSecurityGroupSecurityRulesDetails": UpdateNetworkSecurityGroupSecurityRulesDetails,
    "UpdatePrivateIpDetails": UpdatePrivateIpDetails,
    "UpdatePublicIpDetails": UpdatePublicIpDetails,
    "UpdatePublicIpPoolDetails": UpdatePublicIpPoolDetails,
    "UpdateRemotePeeringConnectionDetails": UpdateRemotePeeringConnectionDetails,
    "UpdateRouteTableDetails": UpdateRouteTableDetails,
    "UpdateSecurityListDetails": UpdateSecurityListDetails,
    "UpdateSecurityRuleDetails": UpdateSecurityRuleDetails,
    "UpdateServiceGatewayDetails": UpdateServiceGatewayDetails,
    "UpdateSubnetDetails": UpdateSubnetDetails,
    "UpdateTunnelCpeDeviceConfigDetails": UpdateTunnelCpeDeviceConfigDetails,
    "UpdateVcnDetails": UpdateVcnDetails,
    "UpdateVirtualCircuitDetails": UpdateVirtualCircuitDetails,
    "UpdateVlanDetails": UpdateVlanDetails,
    "UpdateVnicDetails": UpdateVnicDetails,
    "UpdateVolumeBackupDetails": UpdateVolumeBackupDetails,
    "UpdateVolumeBackupPolicyDetails": UpdateVolumeBackupPolicyDetails,
    "UpdateVolumeDetails": UpdateVolumeDetails,
    "UpdateVolumeGroupBackupDetails": UpdateVolumeGroupBackupDetails,
    "UpdateVolumeGroupDetails": UpdateVolumeGroupDetails,
    "UpdateVolumeKmsKeyDetails": UpdateVolumeKmsKeyDetails,
    "UpdatedNetworkSecurityGroupSecurityRules": UpdatedNetworkSecurityGroupSecurityRules,
    "Vcn": Vcn,
    "VirtualCircuit": VirtualCircuit,
    "VirtualCircuitBandwidthShape": VirtualCircuitBandwidthShape,
    "VirtualCircuitPublicPrefix": VirtualCircuitPublicPrefix,
    "Vlan": Vlan,
    "Vnic": Vnic,
    "VnicAttachment": VnicAttachment,
    "Volume": Volume,
    "VolumeAttachment": VolumeAttachment,
    "VolumeBackup": VolumeBackup,
    "VolumeBackupPolicy": VolumeBackupPolicy,
    "VolumeBackupPolicyAssignment": VolumeBackupPolicyAssignment,
    "VolumeBackupSchedule": VolumeBackupSchedule,
    "VolumeGroup": VolumeGroup,
    "VolumeGroupBackup": VolumeGroupBackup,
    "VolumeGroupSourceDetails": VolumeGroupSourceDetails,
    "VolumeGroupSourceFromVolumeGroupBackupDetails": VolumeGroupSourceFromVolumeGroupBackupDetails,
    "VolumeGroupSourceFromVolumeGroupDetails": VolumeGroupSourceFromVolumeGroupDetails,
    "VolumeGroupSourceFromVolumesDetails": VolumeGroupSourceFromVolumesDetails,
    "VolumeKmsKey": VolumeKmsKey,
    "VolumeSourceDetails": VolumeSourceDetails,
    "VolumeSourceFromVolumeBackupDetails": VolumeSourceFromVolumeBackupDetails,
    "VolumeSourceFromVolumeDetails": VolumeSourceFromVolumeDetails
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ScopeFilter(object):
    """
    Scope filter to reduce the scope of the query.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ScopeFilter object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param field_name:
            The value to assign to the field_name property of this ScopeFilter.
        :type field_name: str

        :param values:
            The value to assign to the values property of this ScopeFilter.
        :type values: list[object]

        """
        self.swagger_types = {
            'field_name': 'str',
            'values': 'list[object]'
        }

        self.attribute_map = {
            'field_name': 'fieldName',
            'values': 'values'
        }

        self._field_name = None
        self._values = None

    @property
    def field_name(self):
        """
        **[Required]** Gets the field_name of this ScopeFilter.
        Field must be a valid enterprise logging out-of-the-box field.


        :return: The field_name of this ScopeFilter.
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """
        Sets the field_name of this ScopeFilter.
        Field must be a valid enterprise logging out-of-the-box field.


        :param field_name: The field_name of this ScopeFilter.
        :type: str
        """
        self._field_name = field_name

    @property
    def values(self):
        """
        **[Required]** Gets the values of this ScopeFilter.
        Field values that will be used to filter the query scope. Please note all values should reflect the fields data type otherwise the query is subject to fail.


        :return: The values of this ScopeFilter.
        :rtype: list[object]
        """
        return self._values

    @values.setter
    def values(self, values):
        """
        Sets the values of this ScopeFilter.
        Field values that will be used to filter the query scope. Please note all values should reflect the fields data type otherwise the query is subject to fail.


        :param values: The values of this ScopeFilter.
        :type: list[object]
        """
        self._values = values

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AddWorkerNodesDetails(object):
    """
    The information about additionaly added nodes
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AddWorkerNodesDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cluster_admin_password:
            The value to assign to the cluster_admin_password property of this AddWorkerNodesDetails.
        :type cluster_admin_password: str

        :param number_of_worker_nodes:
            The value to assign to the number_of_worker_nodes property of this AddWorkerNodesDetails.
        :type number_of_worker_nodes: int

        """
        self.swagger_types = {
            'cluster_admin_password': 'str',
            'number_of_worker_nodes': 'int'
        }

        self.attribute_map = {
            'cluster_admin_password': 'clusterAdminPassword',
            'number_of_worker_nodes': 'numberOfWorkerNodes'
        }

        self._cluster_admin_password = None
        self._number_of_worker_nodes = None

    @property
    def cluster_admin_password(self):
        """
        **[Required]** Gets the cluster_admin_password of this AddWorkerNodesDetails.
        Base-64 encoded password for Cloudera Manager admin user


        :return: The cluster_admin_password of this AddWorkerNodesDetails.
        :rtype: str
        """
        return self._cluster_admin_password

    @cluster_admin_password.setter
    def cluster_admin_password(self, cluster_admin_password):
        """
        Sets the cluster_admin_password of this AddWorkerNodesDetails.
        Base-64 encoded password for Cloudera Manager admin user


        :param cluster_admin_password: The cluster_admin_password of this AddWorkerNodesDetails.
        :type: str
        """
        self._cluster_admin_password = cluster_admin_password

    @property
    def number_of_worker_nodes(self):
        """
        **[Required]** Gets the number_of_worker_nodes of this AddWorkerNodesDetails.
        Number of additional worker nodes for the BDS instance


        :return: The number_of_worker_nodes of this AddWorkerNodesDetails.
        :rtype: int
        """
        return self._number_of_worker_nodes

    @number_of_worker_nodes.setter
    def number_of_worker_nodes(self, number_of_worker_nodes):
        """
        Sets the number_of_worker_nodes of this AddWorkerNodesDetails.
        Number of additional worker nodes for the BDS instance


        :param number_of_worker_nodes: The number_of_worker_nodes of this AddWorkerNodesDetails.
        :type: int
        """
        self._number_of_worker_nodes = number_of_worker_nodes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateVaultDetails(object):
    """
    CreateVaultDetails model.
    """

    #: A constant which can be used with the vault_type property of a CreateVaultDetails.
    #: This constant has a value of "VIRTUAL_PRIVATE"
    VAULT_TYPE_VIRTUAL_PRIVATE = "VIRTUAL_PRIVATE"

    #: A constant which can be used with the vault_type property of a CreateVaultDetails.
    #: This constant has a value of "DEFAULT"
    VAULT_TYPE_DEFAULT = "DEFAULT"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateVaultDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateVaultDetails.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateVaultDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateVaultDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateVaultDetails.
        :type freeform_tags: dict(str, str)

        :param vault_type:
            The value to assign to the vault_type property of this CreateVaultDetails.
            Allowed values for this property are: "VIRTUAL_PRIVATE", "DEFAULT"
        :type vault_type: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'vault_type': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'vault_type': 'vaultType'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._vault_type = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateVaultDetails.
        The OCID of the compartment where you want to create this vault.


        :return: The compartment_id of this CreateVaultDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateVaultDetails.
        The OCID of the compartment where you want to create this vault.


        :param compartment_id: The compartment_id of this CreateVaultDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateVaultDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateVaultDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateVaultDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateVaultDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateVaultDetails.
        A user-friendly name for the vault. It does not have to be unique, and it is changeable.
        Avoid entering confidential information.


        :return: The display_name of this CreateVaultDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateVaultDetails.
        A user-friendly name for the vault. It does not have to be unique, and it is changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this CreateVaultDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateVaultDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateVaultDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateVaultDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateVaultDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def vault_type(self):
        """
        **[Required]** Gets the vault_type of this CreateVaultDetails.
        The type of vault to create. Each type of vault stores the key with different degrees of isolation and has different options and pricing.

        Allowed values for this property are: "VIRTUAL_PRIVATE", "DEFAULT"


        :return: The vault_type of this CreateVaultDetails.
        :rtype: str
        """
        return self._vault_type

    @vault_type.setter
    def vault_type(self, vault_type):
        """
        Sets the vault_type of this CreateVaultDetails.
        The type of vault to create. Each type of vault stores the key with different degrees of isolation and has different options and pricing.


        :param vault_type: The vault_type of this CreateVaultDetails.
        :type: str
        """
        allowed_values = ["VIRTUAL_PRIVATE", "DEFAULT"]
        if not value_allowed_none_or_none_sentinel(vault_type, allowed_values):
            raise ValueError(
                "Invalid value for `vault_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._vault_type = vault_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
